@@ -1,7 +1,7 @@
 /*
  * dvbconfigdialog.cpp
  *
- * Copyright (C) 2007-2009 Christoph Pfister <christophpfister@gmail.com>
+ * Copyright (C) 2007-2011 Christoph Pfister <christophpfister@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <QBoxLayout>
 #include <QButtonGroup>
 #include <QCheckBox>
+#include <QDesktopServices>
 #include <QLabel>
 #include <QProgressBar>
 #include <QPushButton>
@@ -35,14 +36,17 @@
 #include <KIO/Job>
 #include <KLineEdit>
 #include <KLocale>
+#include <KStandardDirs>
 #include <KTabWidget>
 #include "dvbconfig.h"
 #include "dvbdevice.h"
 #include "dvbmanager.h"
+#include "dvbrecording.h"
 
 DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : KDialog(parent),
 	manager(manager_)
 {
+
 	setCaption(i18nc("@title:window", "Configure Television"));
 
 	tabWidget = new KTabWidget(this);
@@ -59,7 +63,7 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : KDialo
 	gridLayout->addWidget(recordingFolderEdit, 0, 1);
 
 	QToolButton *toolButton = new QToolButton(widget);
-	toolButton->setIcon(KIcon("document-open-folder"));
+	toolButton->setIcon(KIcon(QLatin1String("document-open-folder")));
 	toolButton->setToolTip(i18n("Select Folder"));
 	connect(toolButton, SIGNAL(clicked()), this, SLOT(changeRecordingFolder()));
 	gridLayout->addWidget(toolButton, 0, 2);
@@ -71,7 +75,7 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : KDialo
 	gridLayout->addWidget(timeShiftFolderEdit, 1, 1);
 
 	toolButton = new QToolButton(widget);
-	toolButton->setIcon(KIcon("document-open-folder"));
+	toolButton->setIcon(KIcon(QLatin1String("document-open-folder")));
 	toolButton->setToolTip(i18n("Select Folder"));
 	connect(toolButton, SIGNAL(clicked()), this, SLOT(changeTimeShiftFolder()));
 	gridLayout->addWidget(toolButton, 1, 2);
@@ -93,6 +97,39 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : KDialo
 	gridLayout->addWidget(endMarginBox, 3, 1);
 	boxLayout->addLayout(gridLayout);
 
+	gridLayout->addWidget(new QLabel(i18n("Naming style for recordings:")), 4, 0);
+
+	namingFormat = new KLineEdit(widget);
+	namingFormat->setText(manager->getNamingFormat());
+	namingFormat->setToolTip(i18n("The following substitutions work: \"%year\" for year (YYYY) and the following: %month, %day, %hour, %min, %sec, %channel and %title"));
+	connect(namingFormat, SIGNAL(textChanged(QString)), this, SLOT(namingFormatChanged(QString)));
+
+	gridLayout->addWidget(namingFormat, 4, 1);
+	boxLayout->addLayout(gridLayout);
+
+	validPixmap = KIcon(QLatin1String("dialog-ok-apply")).pixmap(KIconLoader::SizeSmallMedium);
+	invalidPixmap = KIcon(QLatin1String("dialog-cancel")).pixmap(KIconLoader::SizeSmallMedium);
+
+	namingFormatValidLabel = new QLabel(widget);
+	namingFormatValidLabel->setPixmap(validPixmap);
+	gridLayout->addWidget(namingFormatValidLabel, 4,2);
+
+	gridLayout->addWidget(new QLabel(i18n("Regex for automatic recording:")), 5, 0);
+
+	regexLineEdit = new KLineEdit(widget);
+	regexLineEdit->setText(manager->getRecordingRegex());
+	regexLineEdit->setToolTip(i18n("Automatically schedules recordings for matching titles."));
+	gridLayout->addWidget(regexLineEdit, 5, 1);
+
+	gridLayout->addWidget(new QLabel(i18n("Action after recording finishes.")),	6, 0);
+
+	actionAfterRecordingLineEdit = new KLineEdit(widget);
+	actionAfterRecordingLineEdit->setText(manager->getActionAfterRecording());
+	actionAfterRecordingLineEdit->setToolTip(i18n("Leave empty for no command."));
+	gridLayout->addWidget(actionAfterRecordingLineEdit, 6, 1);
+
+	boxLayout->addLayout(gridLayout);
+
 	gridLayout = new QGridLayout();
 	gridLayout->addWidget(new QLabel(i18n("Use ISO 8859-1 charset instead of ISO 6937:")),
 		1, 0);
@@ -100,6 +137,13 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : KDialo
 	override6937CharsetBox = new QCheckBox(widget);
 	override6937CharsetBox->setChecked(manager->override6937Charset());
 	gridLayout->addWidget(override6937CharsetBox, 1, 1);
+
+	gridLayout->addWidget(new QLabel(i18n("Create info files to accompany EPG recordings.")),
+		2, 0);
+	createInfoFileBox = new QCheckBox(widget);
+	createInfoFileBox->setChecked(manager->createInfoFile());
+	gridLayout->addWidget(createInfoFileBox, 2, 1);
+
 	boxLayout->addLayout(gridLayout);
 
 	QFrame *frame = new QFrame(widget);
@@ -113,6 +157,11 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : KDialo
 	connect(pushButton, SIGNAL(clicked()), this, SLOT(updateScanFile()));
 	boxLayout->addWidget(pushButton);
 
+	QPushButton *openScanFileButton = new QPushButton(i18n("Edit scanfile"), widget);
+	connect(openScanFileButton, SIGNAL(clicked()), this, SLOT(openScanFile()));
+	boxLayout->addWidget(openScanFileButton);
+	openScanFileButton->setToolTip(i18n("You can add channels manually to this file before scanning for them."));
+
 	frame = new QFrame(widget);
 	frame->setFrameShape(QFrame::HLine);
 	boxLayout->addWidget(frame);
@@ -128,8 +177,8 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : KDialo
 	connect(latitudeEdit, SIGNAL(textChanged(QString)), this, SLOT(latitudeChanged(QString)));
 	gridLayout->addWidget(latitudeEdit, 0, 2);
 
-	validPixmap = KIcon("dialog-ok-apply").pixmap(KIconLoader::SizeSmallMedium);
-	invalidPixmap = KIcon("dialog-cancel").pixmap(KIconLoader::SizeSmallMedium);
+	validPixmap = KIcon(QLatin1String("dialog-ok-apply")).pixmap(KIconLoader::SizeSmallMedium);
+	invalidPixmap = KIcon(QLatin1String("dialog-cancel")).pixmap(KIconLoader::SizeSmallMedium);
 
 	latitudeValidLabel = new QLabel(widget);
 	latitudeValidLabel->setPixmap(validPixmap);
@@ -153,7 +202,7 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : KDialo
 
 	// FIXME more general options
 
-	tabWidget->addTab(widget, KIcon("configure"), i18n("General Options"));
+	tabWidget->addTab(widget, KIcon(QLatin1String("configure")), i18n("General Options"));
 
 	int i = 1;
 
@@ -165,7 +214,7 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : KDialo
 			this, SLOT(moveRight(DvbConfigPage*)));
 		connect(configPage, SIGNAL(remove(DvbConfigPage*)),
 			this, SLOT(remove(DvbConfigPage*)));
-		tabWidget->addTab(configPage, KIcon("video-television"), i18n("Device %1", i));
+		tabWidget->addTab(configPage, KIcon(QLatin1String("video-television")), i18n("Device %1", i));
 		configPages.append(configPage);
 		++i;
 	}
@@ -210,6 +259,12 @@ void DvbConfigDialog::updateScanFile()
 	dialog->show();
 }
 
+void DvbConfigDialog::openScanFile()
+{
+	QString file(KStandardDirs::locateLocal("appdata", QLatin1String("scanfile.dvb")));
+	QDesktopServices::openUrl(QUrl(file));
+}
+
 void DvbConfigDialog::latitudeChanged(const QString &text)
 {
 	bool ok;
@@ -234,6 +289,24 @@ void DvbConfigDialog::longitudeChanged(const QString &text)
 	}
 }
 
+void DvbConfigDialog::namingFormatChanged(QString text)
+{
+	QString temp = text.replace("%year", " ");
+	temp = temp.replace("%month", " ");
+	temp = temp.replace("%day", " ");
+	temp = temp.replace("%hour", " ");
+	temp = temp.replace("%min", " ");
+	temp = temp.replace("%sec"," ");
+	temp = temp.replace("%channel", " ");
+	temp = temp.replace("%title", " ");
+
+	if (!temp.contains("%")) {
+		namingFormatValidLabel->setPixmap(validPixmap);
+	} else {
+		namingFormatValidLabel->setPixmap(invalidPixmap);
+	}
+}
+
 void DvbConfigDialog::moveLeft(DvbConfigPage *configPage)
 {
 	int index = configPages.indexOf(configPage);
@@ -255,7 +328,7 @@ void DvbConfigDialog::moveLeft(DvbConfigPage *configPage)
 	}
 
 	// configPages and tabWidget indexes differ by one
-	tabWidget->insertTab(index, configPages.at(index - 1), KIcon("video-television"),
+	tabWidget->insertTab(index, configPages.at(index - 1), KIcon(QLatin1String("video-television")),
 		i18n("Device %1", index));
 	tabWidget->setTabText(index + 1, i18n("Device %1", index + 1));
 	tabWidget->setCurrentIndex(index);
@@ -282,7 +355,7 @@ void DvbConfigDialog::moveRight(DvbConfigPage *configPage)
 	}
 
 	// configPages and tabWidget indexes differ by one
-	tabWidget->insertTab(index, configPages.at(index - 1), KIcon("video-television"),
+	tabWidget->insertTab(index, configPages.at(index - 1), KIcon(QLatin1String("video-television")),
 		i18n("Device %1", index));
 	tabWidget->setTabText(index + 1, i18n("Device %1", index + 1));
 	tabWidget->setCurrentIndex(index + 1);
@@ -348,9 +421,13 @@ void DvbConfigDialog::accept()
 {
 	manager->setRecordingFolder(recordingFolderEdit->text());
 	manager->setTimeShiftFolder(timeShiftFolderEdit->text());
+	manager->setNamingFormat(namingFormat->text());
+	manager->setRecordingRegex(regexLineEdit->text());
+	manager->setActionAfterRecording(actionAfterRecordingLineEdit->text());
 	manager->setBeginMargin(beginMarginBox->value() * 60);
 	manager->setEndMargin(endMarginBox->value() * 60);
 	manager->setOverride6937Charset(override6937CharsetBox->isChecked());
+	manager->setCreateInfoFile(createInfoFileBox->isChecked());
 
 	bool latitudeOk;
 	bool longitudeOk;
@@ -371,6 +448,7 @@ void DvbConfigDialog::accept()
 	}
 
 	manager->updateDeviceConfigs(configUpdates);
+	manager->getRecordingModel()->findNewRecordings();
 
 	KDialog::accept();
 }
@@ -396,8 +474,8 @@ DvbScanFileDownloadDialog::DvbScanFileDownloadDialog(DvbManager *manager_, QWidg
 	job = KIO::get(KUrl("http://kaffeine.kde.org/scanfile.dvb.qz"), KIO::NoReload,
 		       KIO::HideProgressInfo); // FIXME NoReload or Reload?
 	job->setAutoDelete(false);
-	connect(job, SIGNAL(percent(KJob*,unsigned long)),
-		this, SLOT(progressChanged(KJob*,unsigned long)));
+	connect(job, SIGNAL(percent(KJob*,ulong)),
+		this, SLOT(progressChanged(KJob*,ulong)));
 	connect(job, SIGNAL(data(KIO::Job*,QByteArray)),
 		this, SLOT(dataArrived(KIO::Job*,QByteArray)));
 	connect(job, SIGNAL(result(KJob*)), this, SLOT(jobFinished()));
@@ -410,7 +488,7 @@ DvbScanFileDownloadDialog::~DvbScanFileDownloadDialog()
 
 void DvbScanFileDownloadDialog::progressChanged(KJob *, unsigned long percent)
 {
-	progressBar->setValue(percent);
+	progressBar->setValue(int(percent));
 }
 
 void DvbScanFileDownloadDialog::dataArrived(KIO::Job *, const QByteArray &data)
@@ -453,22 +531,22 @@ DvbConfigPage::DvbConfigPage(QWidget *parent, DvbManager *manager,
 	boxLayout->addWidget(new QLabel(i18n("Name: %1", deviceConfig->frontendName)));
 
 	QBoxLayout *horizontalLayout = new QHBoxLayout();
-	moveLeftButton = new QPushButton(KIcon("arrow-left"), i18n("Move Left"), this);
+	moveLeftButton = new QPushButton(KIcon(QLatin1String("arrow-left")), i18n("Move Left"), this);
 	connect(moveLeftButton, SIGNAL(clicked()), this, SLOT(moveLeft()));
 	horizontalLayout->addWidget(moveLeftButton);
 
 	if (deviceConfig->device != NULL) {
-		QPushButton *pushButton = new QPushButton(KIcon("edit-undo"), i18n("Reset"), this);
+		QPushButton *pushButton = new QPushButton(KIcon(QLatin1String("edit-undo")), i18n("Reset"), this);
 		connect(pushButton, SIGNAL(clicked()), this, SIGNAL(resetConfig()));
 		horizontalLayout->addWidget(pushButton);
 	} else {
 		QPushButton *pushButton =
-			new QPushButton(KIcon("edit-delete"), i18nc("@action", "Remove"), this);
+			new QPushButton(KIcon(QLatin1String("edit-delete")), i18nc("@action", "Remove"), this);
 		connect(pushButton, SIGNAL(clicked()), this, SLOT(removeConfig()));
 		horizontalLayout->addWidget(pushButton);
 	}
 
-	moveRightButton = new QPushButton(KIcon("arrow-right"), i18n("Move Right"), this);
+	moveRightButton = new QPushButton(KIcon(QLatin1String("arrow-right")), i18n("Move Right"), this);
 	connect(moveRightButton, SIGNAL(clicked()), this, SLOT(moveRight()));
 	horizontalLayout->addWidget(moveRightButton);
 	boxLayout->addLayout(horizontalLayout);
@@ -636,11 +714,11 @@ DvbConfigObject::DvbConfigObject(QWidget *parent, QBoxLayout *layout, DvbManager
 		break;
 	case DvbConfigBase::DvbT:
 		defaultName = i18n("Terrestrial");
-		sources.append("AUTO-Normal");
-		sources.append("AUTO-Offsets");
-		sources.append("AUTO-Australia");
-		sources.append("AUTO-Italy");
-		sources.append("AUTO-Taiwan");
+		sources.append(QLatin1String("AUTO-Normal"));
+		sources.append(QLatin1String("AUTO-Offsets"));
+		sources.append(QLatin1String("AUTO-Australia"));
+		sources.append(QLatin1String("AUTO-Italy"));
+		sources.append(QLatin1String("AUTO-Taiwan"));
 		sources += manager->getScanSources(DvbManager::DvbT);
 		sourceIndex = sources.indexOf(config->scanSource);
 		sources.replace(0, i18n("Autoscan"));
@@ -710,19 +788,19 @@ void DvbConfigObject::sourceChanged(int index)
 
 		switch (index - 1) {
 		case 0:
-			config->scanSource = "AUTO-Normal";
+			config->scanSource = QLatin1String("AUTO-Normal");
 			break;
 		case 1:
-			config->scanSource = "AUTO-Offsets";
+			config->scanSource = QLatin1String("AUTO-Offsets");
 			break;
 		case 2:
-			config->scanSource = "AUTO-Australia";
+			config->scanSource = QLatin1String("AUTO-Australia");
 			break;
 		case 3:
-			config->scanSource = "AUTO-Italy";
+			config->scanSource = QLatin1String("AUTO-Italy");
 			break;
 		case 4:
-			config->scanSource = "AUTO-Taiwan";
+			config->scanSource = QLatin1String("AUTO-Taiwan");
 			break;
 		}
 	} else {
