@@ -1,7 +1,7 @@
 /*
  * dvbconfigdialog.h
  *
- * Copyright (C) 2007-2009 Christoph Pfister <christophpfister@gmail.com>
+ * Copyright (C) 2007-2011 Christoph Pfister <christophpfister@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@ class QProgressBar;
 class QSpinBox;
 class QTreeWidget;
 class KComboBox;
+class QComboBox;
 class KJob;
 class KLineEdit;
 class KTabWidget;
@@ -59,8 +60,10 @@ private slots:
 	void changeRecordingFolder();
 	void changeTimeShiftFolder();
 	void updateScanFile();
+	void openScanFile();
 	void latitudeChanged(const QString &text);
 	void longitudeChanged(const QString &text);
+	void namingFormatChanged(QString text);
 	void moveLeft(DvbConfigPage *configPage);
 	void moveRight(DvbConfigPage *configPage);
 	void remove(DvbConfigPage *configPage);
@@ -77,14 +80,19 @@ private:
 	KLineEdit *timeShiftFolderEdit;
 	QSpinBox *beginMarginBox;
 	QSpinBox *endMarginBox;
+	KLineEdit *namingFormat;
 	QCheckBox *override6937CharsetBox;
+	QCheckBox *createInfoFileBox;
 	KLineEdit *latitudeEdit;
 	KLineEdit *longitudeEdit;
 	QPixmap validPixmap;
 	QPixmap invalidPixmap;
 	QLabel *latitudeValidLabel;
 	QLabel *longitudeValidLabel;
+	QLabel *namingFormatValidLabel;
 	QList<DvbConfigPage *> configPages;
+	KLineEdit *regexLineEdit;
+	KLineEdit *actionAfterRecordingLineEdit;
 };
 
 class DvbScanFileDownloadDialog : public KDialog
