@@ -1,7 +1,7 @@
 /*
  * dvbdevice.cpp
  *
- * Copyright (C) 2007-2010 Christoph Pfister <christophpfister@gmail.com>
+ * Copyright (C) 2007-2011 Christoph Pfister <christophpfister@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,9 +23,9 @@
 
 #include <QCoreApplication>
 #include <QDir>
-#include <KDebug>
 #include <cmath>
 #include <unistd.h>
+#include "../log.h"
 #include "dvbconfig.h"
 #include "dvbmanager.h"
 #include "dvbsi.h"
@@ -71,7 +71,7 @@ void DvbSectionFilterInternal::processData(const char data[188])
 {
 	if ((data[3] & 0x10) == 0) {
 		// no payload
-		kDebug() << "no payload";
+		Log("DvbSectionFilterInternal::processData: no payload");
 		return;
 	}
 
@@ -79,12 +79,12 @@ void DvbSectionFilterInternal::processData(const char data[188])
 
 	if (bufferValid) {
 		if (continuity == continuityCounter) {
-			kDebug() << "duplicate packets";
+			Log("DvbSectionFilterInternal::processData: duplicate packets");
 			return;
 		}
 
 		if (continuity != ((continuityCounter + 1) & 0x0f)) {
-			kDebug() << "discontinuity";
+			Log("DvbSectionFilterInternal::processData: discontinuity");
 			bufferValid = false;
 		}
 	}
@@ -104,7 +104,7 @@ void DvbSectionFilterInternal::processData(const char data[188])
 		unsigned char length = data[4];
 
 		if (length > 182) {
-			kDebug() << "no payload or corrupt";
+			Log("DvbSectionFilterInternal::processData: no payload or corrupt");
 			return;
 		}
 
@@ -115,10 +115,10 @@ void DvbSectionFilterInternal::processData(const char data[188])
 	// be careful that playloadLength is > 0 at this point
 
 	if (sectionStart) {
-		unsigned char pointer = payload[0];
+		int pointer = quint8(payload[0]);
 
 		if (pointer >= payloadLength) {
-			kDebug() << "invalid pointer";
+			Log("DvbSectionFilterInternal::processData: invalid pointer");
 			pointer = (payloadLength - 1);
 		}
 
@@ -151,7 +151,7 @@ void DvbSectionFilterInternal::processSections(bool force)
 
 		if ((end - it) < 3) {
 			if (force) {
-				kDebug() << "stray data";
+				Log("DvbSectionFilterInternal::processSections: stray data");
 				it = end;
 			}
 
@@ -162,12 +162,12 @@ void DvbSectionFilterInternal::processSections(bool force)
 			static_cast<unsigned char>(it[2])) + 3);
 
 		if (force && (sectionEnd > end)) {
-			kDebug() << "short section";
+			Log("DvbSectionFilterInternal::processSections: short section");
 			sectionEnd = end;
 		}
 
 		if (sectionEnd <= end) {
-			int size = (sectionEnd - it);
+			int size = int(sectionEnd - it);
 			int crc = DvbStandardSection::verifyCrc32(it, size);
 			bool crcOk;
 
@@ -206,7 +206,7 @@ void DvbSectionFilterInternal::processSections(bool force)
 		break;
 	}
 
-	buffer.remove(0, it - buffer.constBegin());
+	buffer.remove(0, int(it - buffer.constBegin()));
 }
 
 class DvbDataDumper : public QFile, public DvbPidFilter
@@ -220,11 +220,11 @@ public:
 
 DvbDataDumper::DvbDataDumper()
 {
-	setFileName(QDir::homePath() + '/' + "KaffeineDvbDump-" + QString::number(qrand(), 16) +
-		".bin");
+	setFileName(QDir::homePath() + QLatin1String("/KaffeineDvbDump-") + QString::number(qrand(), 16) +
+		QLatin1String(".bin"));
 
 	if (!open(QIODevice::WriteOnly | QIODevice::Truncate)) {
-		kWarning() << "cannot open" << fileName();
+		Log("DvbDataDumper::DvbDataDumper: cannot open") << fileName();
 	}
 }
 
@@ -322,21 +322,21 @@ void DvbDevice::tune(const DvbTransponder &transponder)
 	if (config->switchFrequency != 0) {
 		// dual LO (low / high)
 		if (frequency < config->switchFrequency) {
-			frequency = abs(frequency - config->lowBandFrequency);
+			frequency = qAbs(frequency - config->lowBandFrequency);
 		} else {
-			frequency = abs(frequency - config->highBandFrequency);
+			frequency = qAbs(frequency - config->highBandFrequency);
 			highBand = true;
 		}
 	} else if (config->highBandFrequency != 0) {
 		// single LO (horizontal / vertical)
 		if (horPolar) {
-			frequency = abs(frequency - config->lowBandFrequency);
+			frequency = qAbs(frequency - config->lowBandFrequency);
 		} else {
-			frequency = abs(frequency - config->highBandFrequency);
+			frequency = qAbs(frequency - config->highBandFrequency);
 		}
 	} else {
 		// single LO
-		frequency = abs(frequency - config->lowBandFrequency);
+		frequency = qAbs(frequency - config->lowBandFrequency);
 	}
 
 	// tone off
@@ -353,8 +353,8 @@ void DvbDevice::tune(const DvbTransponder &transponder)
 
 	switch (config->configuration) {
 	case DvbConfigBase::DiseqcSwitch: {
-		char cmd[] = { 0xe0, 0x10, 0x38, 0x00 };
-		cmd[3] = 0xf0 | (config->lnbNumber << 2) | (horPolar ? 2 : 0) | (highBand ? 1 : 0);
+		char cmd[] = { char(0xe0), 0x10, 0x38, 0x00 };
+		cmd[3] = 0xf0 | char(config->lnbNumber << 2) | (horPolar ? 2 : 0) | (highBand ? 1 : 0);
 		backend->sendMessage(cmd, sizeof(cmd));
 		usleep(15000);
 
@@ -365,21 +365,22 @@ void DvbDevice::tune(const DvbTransponder &transponder)
 
 	case DvbConfigBase::UsalsRotor: {
 		QString source = config->scanSource;
-		source.remove(0, source.lastIndexOf('-') + 1);
+		source.remove(0, source.lastIndexOf(QLatin1Char('-')) + 1);
 
 		bool ok = false;
 		double orbitalPosition = 0;
 
-		if (source.endsWith('E')) {
+		if (source.endsWith(QLatin1Char('E'))) {
 			source.chop(1);
 			orbitalPosition = source.toDouble(&ok);
-		} else if (source.endsWith('W')) {
+		} else if (source.endsWith(QLatin1Char('W'))) {
 			source.chop(1);
 			orbitalPosition = (-source.toDouble(&ok));
 		}
 
 		if (!ok) {
-			kWarning() << "cannot extract orbital position from" << config->scanSource;
+			Log("DvbDevice::tune: cannot extract orbital position from") <<
+				config->scanSource;
 		}
 
 		double radius = 6378;
@@ -391,15 +392,15 @@ void DvbDevice::tune(const DvbTransponder &transponder)
 
 		if (angle >= 0) {
 			// east
-			value = ((16 * angle * 180 / M_PI) + 0.5);
+			value = int((16 * angle * 180 / M_PI) + 0.5);
 			value |= 0xe000;
 		} else {
 			// west
-			value = ((16 * (-angle) * 180 / M_PI) + 0.5);
+			value = int((16 * (-angle) * 180 / M_PI) + 0.5);
 			value |= 0xd000;
 		}
 
-		char cmd[] = { 0xe0, 0x31, 0x6e, (value / 256), (value % 256) };
+		char cmd[] = { char(0xe0), 0x31, 0x6e, char(value / 256), char(value % 256) };
 		backend->sendMessage(cmd, sizeof(cmd));
 		usleep(15000);
 		moveRotor = true;
@@ -407,7 +408,7 @@ void DvbDevice::tune(const DvbTransponder &transponder)
 	    }
 
 	case DvbConfigBase::PositionsRotor: {
-		char cmd[] = { 0xe0, 0x31, 0x6b, config->lnbNumber };
+		char cmd[] = { char(0xe0), 0x31, 0x6b, char(config->lnbNumber) };
 		backend->sendMessage(cmd, sizeof(cmd));
 		usleep(15000);
 		moveRotor = true;
@@ -443,7 +444,7 @@ void DvbDevice::tune(const DvbTransponder &transponder)
 void DvbDevice::autoTune(const DvbTransponder &transponder)
 {
 	if (transponder.getTransmissionType() != DvbTransponderBase::DvbT) {
-		kWarning() << "can't handle != DVB-T";
+		Log("DvbDevice::autoTune: can't handle != DVB-T");
 		return;
 	}
 
@@ -493,7 +494,8 @@ bool DvbDevice::addPidFilter(int pid, DvbPidFilter *filter)
 	}
 
 	if (it->filters.contains(filter)) {
-		kWarning() << "using the same filter for the same pid more than once";
+		Log("DvbDevice::addPidFilter: "
+		    "using the same filter for the same pid more than once");
 		return true;
 	}
 
@@ -518,7 +520,8 @@ bool DvbDevice::addSectionFilter(int pid, DvbSectionFilter *filter)
 	}
 
 	if (it->sectionFilters.contains(filter)) {
-		kWarning() << "using the same filter for the same pid more than once";
+		Log("DvbDevice::addSectionFilter: "
+		    "using the same filter for the same pid more than once");
 		return true;
 	}
 
@@ -539,7 +542,7 @@ void DvbDevice::removePidFilter(int pid, DvbPidFilter *filter)
 	}
 
 	if (index < 0) {
-		kWarning() << "trying to remove a nonexistent filter";
+		Log("DvbDevice::removePidFilter: trying to remove a nonexistent filter");
 		return;
 	}
 
@@ -565,7 +568,7 @@ void DvbDevice::removeSectionFilter(int pid, DvbSectionFilter *filter)
 	}
 
 	if (index < 0) {
-		kWarning() << "trying to remove a nonexistent filter";
+		Log("DvbDevice::removeSectionFilter: trying to remove a nonexistent filter");
 		return;
 	}
 
@@ -584,7 +587,7 @@ void DvbDevice::startDescrambling(const QByteArray &pmtSectionData, QObject *use
 	DvbPmtSection pmtSection(pmtSectionData);
 
 	if (!pmtSection.isValid()) {
-		kWarning() << "pmt section is not valid";
+		Log("DvbDevice::startDescrambling: pmt section is not valid");
 	}
 
 	int serviceId = pmtSection.programNumber();
@@ -603,13 +606,13 @@ void DvbDevice::stopDescrambling(const QByteArray &pmtSectionData, QObject *user
 	DvbPmtSection pmtSection(pmtSectionData);
 
 	if (!pmtSection.isValid()) {
-		kWarning() << "pmt section is not valid";
+		Log("DvbDevice::stopDescrambling: pmt section is not valid");
 	}
 
 	int serviceId = pmtSection.programNumber();
 
 	if (!descramblingServices.contains(serviceId, user)) {
-		kWarning() << "service has not been started";
+		Log("DvbDevice::stopDescrambling: service has not been started");
 		return;
 	}
 
@@ -689,7 +692,7 @@ void DvbDevice::enableDvbDump()
 void DvbDevice::frontendEvent()
 {
 	if (backend->isTuned()) {
-		kDebug() << "tuning succeeded";
+		Log("DvbDevice::frontendEvent: tuning succeeded");
 		frontendTimer.stop();
 		setDeviceState(DeviceTuned);
 		return;
@@ -703,7 +706,7 @@ void DvbDevice::frontendEvent()
 		frontendTimer.stop();
 
 		if (!isAuto) {
-			kWarning() << "tuning failed";
+			Log("DvbDevice::frontendEvent: tuning failed");
 			setDeviceState(DeviceIdle);
 			return;
 		}
@@ -713,7 +716,7 @@ void DvbDevice::frontendEvent()
 
 		if ((signal != -1) && (signal < 15)) {
 			// signal too weak
-			kWarning() << "tuning failed";
+			Log("DvbDevice::frontendEvent: tuning failed");
 			setDeviceState(DeviceIdle);
 			return;
 		}
@@ -811,7 +814,7 @@ void DvbDevice::frontendEvent()
 		if (!carry) {
 			tune(autoTransponder);
 		} else {
-			kWarning() << "tuning failed";
+			Log("DvbDevice::frontendEvent: tuning failed");
 			setDeviceState(DeviceIdle);
 		}
 	}
@@ -853,7 +856,7 @@ void DvbDevice::stop()
 		foreach (DvbPidFilter *filter, it->filters) {
 			if ((filter != &dummyPidFilter) && (filter != dataDumper)) {
 				int pid = it.key();
-				kWarning() << "removing pending filter" << pid << filter;
+				Log("DvbDevice::stop: removing pending filter") << pid;
 				removePidFilter(pid, filter);
 			}
 		}
@@ -864,7 +867,7 @@ void DvbDevice::stop()
 		foreach (DvbSectionFilter *sectionFilter, it->sectionFilters) {
 			if (sectionFilter != &dummySectionFilter) {
 				int pid = it.key();
-				kWarning() << "removing pending filter" << pid << sectionFilter;
+				Log("DvbDevice::stop: removing pending filter") << pid;
 				removeSectionFilter(pid, sectionFilter);
 			}
 		}
