@@ -1,7 +1,7 @@
 /*
  * dvbdevice_linux.cpp
  *
- * Copyright (C) 2007-2010 Christoph Pfister <christophpfister@gmail.com>
+ * Copyright (C) 2007-2011 Christoph Pfister <christophpfister@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,14 +24,22 @@
 #include <Solid/Device>
 #include <Solid/DeviceNotifier>
 #include <Solid/DvbInterface>
-#include <KDebug>
 #include <dmx.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <frontend.h>
 #include <poll.h>
+#include <sys/socket.h>
+#include <sys/un.h>
+#include <sys/types.h>
 #include <sys/ioctl.h>
+#include <sys/stat.h>
+#include <dirent.h>
+#include <sys/inotify.h>
+#include <vector>
+#include <stdlib.h>
 #include <unistd.h>
+#include "../log.h"
 #include "dvbtransponder.h"
 
 // krazy:excludeall=syscalls
@@ -56,10 +64,10 @@ bool DvbLinuxDevice::isReady() const
 void DvbLinuxDevice::startDevice(const QString &deviceId_)
 {
 	Q_ASSERT(!ready);
-	int fd = open(QFile::encodeName(frontendPath), O_RDONLY | O_NONBLOCK);
+	int fd = open(QFile::encodeName(frontendPath).constData(), O_RDONLY | O_NONBLOCK | O_CLOEXEC);
 
 	if (fd < 0) {
-		kWarning() << "cannot open frontend" << frontendPath;
+		Log("DvbLinuxDevice::startDevice: cannot open frontend") << frontendPath;
 		return;
 	}
 
@@ -67,7 +75,8 @@ void DvbLinuxDevice::startDevice(const QString &deviceId_)
 	memset(&frontend_info, 0, sizeof(frontend_info));
 
 	if (ioctl(fd, FE_GET_INFO, &frontend_info) != 0) {
-		kWarning() << "ioctl FE_GET_INFO failed for frontend" << frontendPath;
+		Log("DvbLinuxDevice::startDevice: ioctl FE_GET_INFO failed for frontend") <<
+			frontendPath;
 		close(fd);
 		return;
 	}
@@ -98,8 +107,8 @@ void DvbLinuxDevice::startDevice(const QString &deviceId_)
 		transmissionTypes = Atsc;
 		break;
 	default:
-		kWarning() << "unknown type" << frontend_info.type << "for frontend" <<
-			frontendPath;
+		Log("DvbLinuxDevice::startDevice: unknown type") << frontend_info.type <<
+			QLatin1String("for frontend") << frontendPath;
 		return;
 	}
 
@@ -121,7 +130,7 @@ void DvbLinuxDevice::startDevice(const QString &deviceId_)
 		capabilities |= DvbTGuardIntervalAuto;
 	}
 
-	kDebug() << "found dvb device" << deviceId << '/' << frontendName;
+	Log("DvbLinuxDevice::startDevice: found dvb device") << deviceId << '/' << frontendName;
 	ready = true;
 }
 
@@ -199,17 +208,17 @@ void DvbLinuxDevice::setDeviceEnabled(bool enabled_)
 bool DvbLinuxDevice::acquire()
 {
 	Q_ASSERT(enabled && (frontendFd < 0) && (dvrFd < 0));
-	frontendFd = open(QFile::encodeName(frontendPath), O_RDWR | O_NONBLOCK);
+	frontendFd = open(QFile::encodeName(frontendPath).constData(), O_RDWR | O_NONBLOCK | O_CLOEXEC);
 
 	if (frontendFd < 0) {
-		kWarning() << "cannot open frontend" << frontendPath;
+		Log("DvbLinuxDevice::acquire: cannot open frontend") << frontendPath << frontendFd;
 		return false;
 	}
 
-	dvrFd = open(QFile::encodeName(dvrPath), O_RDONLY | O_NONBLOCK);
+	dvrFd = open(QFile::encodeName(dvrPath).constData(), O_RDONLY | O_NONBLOCK | O_CLOEXEC);
 
 	if (dvrFd < 0) {
-		kWarning() << "cannot open dvr" << dvrPath;
+		Log("DvbLinuxDevice::acquire: cannot open dvr") << dvrPath;
 		close(frontendFd);
 		frontendFd = -1;
 		return false;
@@ -223,7 +232,8 @@ bool DvbLinuxDevice::setTone(SecTone tone)
 	Q_ASSERT(frontendFd >= 0);
 
 	if (ioctl(frontendFd, FE_SET_TONE, (tone == ToneOn) ? SEC_TONE_ON : SEC_TONE_OFF) != 0) {
-		kWarning() << "ioctl FE_SET_TONE failed for frontend" << frontendPath;
+		Log("DvbLinuxDevice::setTone: ioctl FE_SET_TONE failed for frontend") <<
+			frontendPath;
 		return false;
 	}
 
@@ -236,7 +246,8 @@ bool DvbLinuxDevice::setVoltage(SecVoltage voltage)
 
 	if (ioctl(frontendFd, FE_SET_VOLTAGE,
 		  (voltage == Voltage18V) ? SEC_VOLTAGE_18 : SEC_VOLTAGE_13) != 0) {
-		kWarning() << "ioctl FE_SET_VOLTAGE failed for frontend" << frontendPath;
+		Log("DvbLinuxDevice::setVoltage: ioctl FE_SET_VOLTAGE failed for frontend") <<
+			frontendPath;
 		return false;
 	}
 
@@ -249,11 +260,11 @@ bool DvbLinuxDevice::sendMessage(const char *message, int length)
 	dvb_diseqc_master_cmd cmd;
 	memset(&cmd, 0, sizeof(cmd));
 	memcpy(&cmd.msg, message, length);
-	cmd.msg_len = length;
+	cmd.msg_len = char(length);
 
 	if (ioctl(frontendFd, FE_DISEQC_SEND_MASTER_CMD, &cmd) != 0) {
-		kWarning() << "ioctl FE_DISEQC_SEND_MASTER_CMD failed for frontend" <<
-			frontendPath;
+		Log("DvbLinuxDevice::sendMessage: "
+		    "ioctl FE_DISEQC_SEND_MASTER_CMD failed for frontend") << frontendPath;
 		return false;
 	}
 
@@ -266,7 +277,8 @@ bool DvbLinuxDevice::sendBurst(SecBurst burst)
 
 	if (ioctl(frontendFd, FE_DISEQC_SEND_BURST,
 		  (burst == BurstMiniA) ? SEC_MINI_A : SEC_MINI_B) != 0) {
-		kWarning() << "ioctl FE_DISEQC_SEND_BURST failed for frontend" << frontendPath;
+		Log("DvbLinuxDevice::sendBurst: ioctl FE_DISEQC_SEND_BURST failed for frontend") <<
+			frontendPath;
 		return false;
 	}
 
@@ -463,7 +475,8 @@ bool DvbLinuxDevice::tune(const DvbTransponder &transponder)
 		propertyList.num = (sizeof(properties) / sizeof(properties[0]));
 
 		if (ioctl(frontendFd, FE_SET_PROPERTY, &propertyList) != 0) {
-			kWarning() << "ioctl FE_SET_PROPERTY failed for frontend" << frontendPath;
+			Log("DvbLinuxDevice::tune: ioctl FE_SET_PROPERTY failed for frontend") <<
+				frontendPath;
 			return false;
 		}
 
@@ -496,12 +509,14 @@ bool DvbLinuxDevice::tune(const DvbTransponder &transponder)
 		break;
 	    }
 	default:
-		kWarning() << "unknown transmission type" << transponder.getTransmissionType();
+		Log("DvbLinuxDevice::tune: unknown transmission type") <<
+			transponder.getTransmissionType();
 		return false;
 	}
 
 	if (ioctl(frontendFd, FE_SET_FRONTEND, &params) != 0) {
-		kWarning() << "ioctl FE_SET_FRONTEND failed for frontend" << frontendPath;
+		Log("DvbLinuxDevice::tune: ioctl FE_SET_FRONTEND failed for frontend") <<
+			frontendPath;
 		return false;
 	}
 
@@ -516,7 +531,8 @@ bool DvbLinuxDevice::isTuned()
 	memset(&status, 0, sizeof(status));
 
 	if (ioctl(frontendFd, FE_READ_STATUS, &status) != 0) {
-		kWarning() << "ioctl FE_READ_STATUS failed for frontend" << frontendPath;
+		Log("DvbLinuxDevice::isTuned: ioctl FE_READ_STATUS failed for frontend") <<
+			frontendPath;
 		return false;
 	}
 
@@ -529,7 +545,8 @@ int DvbLinuxDevice::getSignal()
 	quint16 signal = 0;
 
 	if (ioctl(frontendFd, FE_READ_SIGNAL_STRENGTH, &signal) != 0) {
-		kWarning() << "ioctl FE_READ_SIGNAL_STRENGTH failed for frontend" << frontendPath;
+		Log("DvbLinuxDevice::getSignal: "
+		    "ioctl FE_READ_SIGNAL_STRENGTH failed for frontend") << frontendPath;
 		return -1;
 	}
 
@@ -547,7 +564,8 @@ int DvbLinuxDevice::getSnr()
 	quint16 snr = 0;
 
 	if (ioctl(frontendFd, FE_READ_SNR, &snr) != 0) {
-		kWarning() << "ioctl FE_READ_SNR failed for frontend" << frontendPath;
+		Log("DvbLinuxDevice::getSnr: ioctl FE_READ_SNR failed for frontend") <<
+			frontendPath;
 		return -1;
 	}
 
@@ -564,27 +582,28 @@ bool DvbLinuxDevice::addPidFilter(int pid)
 	Q_ASSERT(frontendFd >= 0);
 
 	if (dmxFds.contains(pid)) {
-		kWarning() << "pid filter already set up for pid" << pid;
+		Log("DvbLinuxDevice::addPidFilter: pid filter already set up for pid") << pid;
 		return false;
 	}
 
-	int dmxFd = open(QFile::encodeName(demuxPath), O_RDONLY | O_NONBLOCK);
+	int dmxFd = open(QFile::encodeName(demuxPath).constData(), O_RDONLY | O_NONBLOCK | O_CLOEXEC);
 
 	if (dmxFd < 0) {
-		kWarning() << "cannot open demux" << demuxPath;
+		Log("DvbLinuxDevice::addPidFilter: cannot open demux") << demuxPath;
 		return false;
 	}
 
 	dmx_pes_filter_params pes_filter;
 	memset(&pes_filter, 0, sizeof(pes_filter));
-	pes_filter.pid = pid;
+	pes_filter.pid = ushort(pid);
 	pes_filter.input = DMX_IN_FRONTEND;
 	pes_filter.output = DMX_OUT_TS_TAP;
 	pes_filter.pes_type = DMX_PES_OTHER;
 	pes_filter.flags = DMX_IMMEDIATE_START;
 
 	if (ioctl(dmxFd, DMX_SET_PES_FILTER, &pes_filter) != 0) {
-		kWarning() << "cannot set up pid filter for demux" << demuxPath;
+		Log("DvbLinuxDevice::addPidFilter: cannot set up pid filter for demux") <<
+			demuxPath;
 		close(dmxFd);
 		return false;
 	}
@@ -598,7 +617,7 @@ void DvbLinuxDevice::removePidFilter(int pid)
 	Q_ASSERT(frontendFd >= 0);
 
 	if (!dmxFds.contains(pid)) {
-		kWarning() << "no pid filter set up for pid" << pid;
+		Log("DvbLinuxDevice::removePidFilter: no pid filter set up for pid") << pid;
 		return;
 	}
 
@@ -663,7 +682,7 @@ void DvbLinuxDevice::startDvr()
 		}
 
 		if ((dvrPipe[0] < 0) || (dvrPipe[1] < 0)) {
-			kWarning() << "cannot create pipe";
+			Log("DvbLinuxDevice::startDvr: cannot create pipe");
 			return;
 		}
 	}
@@ -674,7 +693,7 @@ void DvbLinuxDevice::startDvr()
 
 	while (true) {
 		int bufferSize = dvrBuffer.bufferSize;
-		int dataSize = read(dvrFd, dvrBuffer.data, bufferSize);
+		int dataSize = int(read(dvrFd, dvrBuffer.data, bufferSize));
 
 		if (dataSize < 0) {
 			if ((errno == EAGAIN) || (errno == EWOULDBLOCK)) {
@@ -685,7 +704,7 @@ void DvbLinuxDevice::startDvr()
 				continue;
 			}
 
-			dataSize = read(dvrFd, dvrBuffer.data, bufferSize);
+			dataSize = int(read(dvrFd, dvrBuffer.data, bufferSize));
 
 			if (dataSize < 0) {
 				if ((errno == EAGAIN) || (errno == EWOULDBLOCK)) {
@@ -696,7 +715,7 @@ void DvbLinuxDevice::startDvr()
 					continue;
 				}
 
-				kWarning() << "cannot read from dvr" << dvrPath;
+				Log("DvbLinuxDevice::startDvr: cannot read from dvr") << dvrPath;
 				return;
 			}
 		}
@@ -715,14 +734,14 @@ void DvbLinuxDevice::stopDvr()
 		Q_ASSERT((dvrPipe[0] >= 0) && (dvrPipe[1] >= 0));
 
 		if (write(dvrPipe[1], " ", 1) != 1) {
-			kWarning() << "cannot write to pipe";
+			Log("DvbLinuxDevice::stopDvr: cannot write to pipe");
 		}
 
 		wait();
 		char data;
 
 		if (read(dvrPipe[0], &data, 1) != 1) {
-			kWarning() << "cannot read from pipe";
+			Log("DvbLinuxDevice::stopDvr: cannot read from pipe");
 		}
 	}
 }
@@ -743,7 +762,7 @@ void DvbLinuxDevice::run()
 				continue;
 			}
 
-			kWarning() << "poll failed";
+			Log("DvbLinuxDevice::run: poll failed");
 			return;
 		}
 
@@ -753,7 +772,7 @@ void DvbLinuxDevice::run()
 
 		while (true) {
 			int bufferSize = dvrBuffer.bufferSize;
-			int dataSize = read(dvrFd, dvrBuffer.data, bufferSize);
+			int dataSize = int(read(dvrFd, dvrBuffer.data, bufferSize));
 
 			if (dataSize < 0) {
 				if ((errno == EAGAIN) || (errno == EWOULDBLOCK)) {
@@ -764,8 +783,8 @@ void DvbLinuxDevice::run()
 					continue;
 				}
 
-				kWarning() << "cannot read from dvr" << dvrPath;
-				dataSize = read(dvrFd, dvrBuffer.data, bufferSize);
+				Log("DvbLinuxDevice::run: cannot read from dvr") << dvrPath;
+				dataSize = int(read(dvrFd, dvrBuffer.data, bufferSize));
 
 				if (dataSize < 0) {
 					if ((errno == EAGAIN) || (errno == EWOULDBLOCK)) {
@@ -776,7 +795,8 @@ void DvbLinuxDevice::run()
 						continue;
 					}
 
-					kWarning() << "cannot read from dvr" << dvrPath;
+					Log("DvbLinuxDevice::run: cannot read from dvr") <<
+						dvrPath;
 					return;
 				}
 			}
@@ -796,15 +816,179 @@ void DvbLinuxDevice::run()
 	}
 }
 
+struct dvbdev {
+        time_t stctime;
+        char checked;
+        char adapter_name[50];
+        char node_name[75];
+        int adapternum;
+        char lnode[20];
+};
+
+class DvbDeviceMonitor : public QThread
+{
+public:
+        DvbDeviceMonitor(DvbLinuxDeviceManager *ddm)
+        {
+                this->ddm = ddm;
+        }
+        ~DvbDeviceMonitor()
+        {
+        }
+        void run() {
+                DIR *dvbdir, *adapterdirp;
+                struct dirent *dp, *dp2;
+                struct stat stbuf;
+                int adapter;
+                int rescan=0;
+                int rv;
+                int ifd;
+                int found=0;
+                char adapterdir[50];
+                char nodename[75];
+                char buffer[1024];
+                struct pollfd pfd;
+                char firstrun_complete=0;
+                std::vector<struct dvbdev*>adapterlist;
+                std::vector<struct dvbdev*>::iterator iter;
+
+                runstate = 1;
+
+                ifd = inotify_init();
+                inotify_add_watch(ifd, "/dev/dvb", IN_CREATE|IN_DELETE);
+                fcntl(ifd, F_SETFL, O_NONBLOCK);
+                pfd.fd = ifd;
+                pfd.events = POLLIN;
+
+                while(runstate) {
+                        if (firstrun_complete) {
+                                rv = poll(&pfd, 1, 100);
+                                switch (rv) {
+                                case -1:
+                                        break;
+                                case 0:
+                                        continue;
+                                default:
+                                        usleep(100000); /* give it some time to settle down */
+                                        while(read(ifd, buffer, 1024)>0);
+                                        break;
+                                }
+                        } else {
+                                firstrun_complete=1;
+                        }
+
+                        dvbdir = opendir("/dev/dvb");
+                        for (iter=adapterlist.begin();iter!=adapterlist.end();iter++) {
+                                (*iter)->checked=0;
+                        }
+                        if (dvbdir) {
+                                while((dp=readdir(dvbdir))!= 0) {
+                                        if (strcmp(dp->d_name, ".") == 0 ||
+                                            strcmp(dp->d_name, "..") == 0)
+                                                continue;
+                                        adapter = strtol(&dp->d_name[7], NULL, 10);
+                                        sprintf(adapterdir, "/dev/dvb/%s", dp->d_name);
+                                        adapterdirp = opendir(adapterdir);
+                                        if (adapterdirp) {
+                                                while((dp2=readdir(adapterdirp))!=0) {
+                                                        found=0;
+                                                        if (strcmp(dp2->d_name, ".")==0 ||
+                                                                strcmp(dp2->d_name, "..")==0)
+                                                                continue;
+                                                        sprintf(nodename, "/dev/dvb/%s/%s", dp->d_name, dp2->d_name);
+                                                        rv = stat(nodename, &stbuf);
+                                                        for (iter=adapterlist.begin();iter!=adapterlist.end();iter++) {
+                                                                if (strcmp((*iter)->node_name, nodename)==0 && (*iter)->stctime == stbuf.st_ctime) {
+                                                                        (*iter)->checked=1;
+                                                                        found=1;
+                                                                        break;
+                                                                }
+                                                        }
+                                                        if (found == 0) {
+                                                                struct dvbdev *dvbdev = (struct dvbdev*)calloc(1, sizeof(struct dvbdev));
+                                                                dvbdev->checked=1;
+                                                                dvbdev->stctime = stbuf.st_ctime;
+                                                                strcpy(dvbdev->adapter_name, dp->d_name);
+                                                                strcpy(dvbdev->node_name, nodename);
+                                                                dvbdev->adapternum = adapter;
+                                                                strcpy(dvbdev->lnode, dp2->d_name);
+                                                                adapterlist.push_back(dvbdev);
+                                                                ddm->componentAdded(dp2->d_name, adapter, 0);
+                                                        }
+
+                                                }
+                                                closedir(adapterdirp);
+                                        }
+                                }
+                                closedir(dvbdir);
+                        }
+                        do {
+                                rescan=0;
+                                for (iter=adapterlist.begin();iter!=adapterlist.end();iter++) {
+                                        if ((*iter)->checked==0) {
+                                                ddm->componentRemoved((*iter)->lnode, (*iter)->adapternum, 0);
+                                                free(*iter);
+                                                adapterlist.erase(iter);
+                                                rescan=1;
+                                                break;
+                                        }
+                                }
+                        } while (rescan!=0);
+                }
+        }
+        void stop() {
+                runstate = 0;
+                wait();
+        }
+private:
+        int runstate;
+        DvbLinuxDeviceManager *ddm;
+};
+
+#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__sun)
+#define MACHADDRESS "/tmp/.mediasocket"
+#else
+#define ADDRESS     "/de/sundtek/mediasocket"  /* addr to connect */
+#endif
+
 DvbLinuxDeviceManager::DvbLinuxDeviceManager(QObject *parent) : QObject(parent)
 {
+        int fd;
+        int len;
+        int ret;
+        struct sockaddr_un saun;
 	QObject *notifier = Solid::DeviceNotifier::instance();
 	connect(notifier, SIGNAL(deviceAdded(QString)), this, SLOT(componentAdded(QString)));
 	connect(notifier, SIGNAL(deviceRemoved(QString)), this, SLOT(componentRemoved(QString)));
+
+        memset(&saun, 0x0, sizeof(struct sockaddr_un));
+        fd = socket(AF_UNIX, SOCK_STREAM, 0);
+        if (fd==-1) {
+		monitor = NULL;
+                return;
+	}
+        saun.sun_family = AF_UNIX;
+#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__sun)
+        strcpy(saun.sun_path, MACHADDRESS);
+        len = sizeof(saun.sun_family) + strlen(saun.sun_path)+1;
+#else
+        strcpy(&saun.sun_path[1], ADDRESS);
+        len = sizeof(saun.sun_family) + strlen(&saun.sun_path[1])+1;
+#endif
+        if ((ret=::connect(fd, (struct sockaddr*)&saun, len)) < 0) {
+                close(fd);
+		monitor = NULL;
+                return;
+        }
+	close(fd);
+	monitor = new DvbDeviceMonitor(this);
+	monitor->start();
 }
 
 DvbLinuxDeviceManager::~DvbLinuxDeviceManager()
 {
+	if (monitor)
+		monitor->stop();
 }
 
 void DvbLinuxDeviceManager::doColdPlug()
@@ -815,6 +999,36 @@ void DvbLinuxDeviceManager::doColdPlug()
 	}
 }
 
+void DvbLinuxDeviceManager::componentAdded(QString node, int adapter, int index) {
+        int deviceIndex = (adapter << 16) | index;
+        char adapterstring[10];
+        DvbLinuxDevice *device = devices.value(deviceIndex, NULL);
+        if (device == NULL) {
+                device = new DvbLinuxDevice(this);
+                devices.insert(deviceIndex, device);
+        }
+        sprintf(adapterstring, "adapter%d", adapter);
+
+        if (node == "frontend0") {
+                device->frontendPath.sprintf("/dev/dvb/%s/%s", adapterstring, node.toAscii().data());
+        } else if (node == "dvr0") {
+                device->dvrPath.sprintf("/dev/dvb/%s/%s", adapterstring, node.toAscii().data());
+        } else if (node == "demux0") {
+                device->demuxPath.sprintf("/dev/dvb/%s/%s", adapterstring, node.toAscii().data());
+        } else {
+                return;
+        }
+
+	if (!device->demuxPath.isEmpty() && !device->dvrPath.isEmpty() &&
+	    !device->frontendPath.isEmpty()) {
+		device->startDevice("");
+
+		if (device->isReady()) {
+			emit deviceAdded(device);
+		}
+	}
+}
+
 void DvbLinuxDeviceManager::componentAdded(const QString &udi)
 {
 	const Solid::DvbInterface *dvbInterface = Solid::Device(udi).as<Solid::DvbInterface>();
@@ -828,12 +1042,14 @@ void DvbLinuxDeviceManager::componentAdded(const QString &udi)
 	QString devicePath = dvbInterface->device();
 
 	if ((adapter < 0) || (adapter > 0x7fff) || (index < 0) || (index > 0x7fff)) {
-		kWarning() << "cannot determine adapter or index for device" << udi;
+		Log("DvbLinuxDeviceManager::componentAdded: "
+		    "cannot determine adapter or index for device") << udi;
 		return;
 	}
 
 	if (devicePath.isEmpty()) {
-		kWarning() << "cannot determine path for device" << udi;
+		Log("DvbLinuxDeviceManager::componentAdded: cannot determine path for device") <<
+			udi;
 		return;
 	}
 
@@ -893,33 +1109,32 @@ void DvbLinuxDeviceManager::componentAdded(const QString &udi)
 
 	if (addDevice && !device->demuxPath.isEmpty() && !device->dvrPath.isEmpty() &&
 	    !device->frontendPath.isEmpty()) {
-		QString path = QString("/sys/class/dvb/dvb%1.frontend%2/").arg(adapter).arg(index);
+		QString path = QString(QLatin1String("/sys/class/dvb/dvb%1.frontend%2/")).arg(adapter).arg(index);
 		QString deviceId;
 
-		if (QFile::exists(path + "device/vendor")) {
+		if (QFile::exists(path + QLatin1String("device/vendor"))) {
 			// PCI device
-			int vendor = readSysAttr(path + "device/vendor");
-			int device = readSysAttr(path + "device/device");
-			int subsystem_vendor = readSysAttr(path + "device/subsystem_vendor");
-			int subsystem_device = readSysAttr(path + "device/subsystem_device");
+			int vendor = readSysAttr(path + QLatin1String("device/vendor"));
+			int pciDevice = readSysAttr(path + QLatin1String("device/device"));
+			int subsystemVendor = readSysAttr(path + QLatin1String("device/subsystem_vendor"));
+			int subsystemDevice = readSysAttr(path + QLatin1String("device/subsystem_device"));
 
-			if ((vendor >= 0) && (device >= 0) && (subsystem_vendor >= 0) &&
-			    (subsystem_device >= 0)) {
-				deviceId = 'P';
-				deviceId += QString("%1").arg(vendor, 4, 16, QChar('0'));
-				deviceId += QString("%1").arg(device, 4, 16, QChar('0'));
-				deviceId += QString("%1").arg(subsystem_vendor, 4, 16, QChar('0'));
-				deviceId += QString("%1").arg(subsystem_device, 4, 16, QChar('0'));
+			if ((vendor >= 0) && (pciDevice >= 0) && (subsystemVendor >= 0) && (subsystemDevice >= 0)) {
+				deviceId = QLatin1Char('P');
+				deviceId += QString(QLatin1String("%1")).arg(vendor, 4, 16, QLatin1Char('0'));
+				deviceId += QString(QLatin1String("%1")).arg(pciDevice, 4, 16, QLatin1Char('0'));
+				deviceId += QString(QLatin1String("%1")).arg(subsystemVendor, 4, 16, QLatin1Char('0'));
+				deviceId += QString(QLatin1String("%1")).arg(subsystemDevice, 4, 16, QLatin1Char('0'));
 			}
-		} else if (QFile::exists(path + "device/idVendor")) {
+		} else if (QFile::exists(path + QLatin1String("device/idVendor"))) {
 			// USB device
-			int vendor = readSysAttr(path + "device/idVendor");
-			int product = readSysAttr(path + "device/idProduct");
+			int vendor = readSysAttr(path + QLatin1String("device/idVendor"));
+			int product = readSysAttr(path + QLatin1String("device/idProduct"));
 
 			if ((vendor >= 0) && (product >= 0)) {
-				deviceId = 'U';
-				deviceId += QString("%1").arg(vendor, 4, 16, QChar('0'));
-				deviceId += QString("%1").arg(product, 4, 16, QChar('0'));
+				deviceId = QLatin1Char('U');
+				deviceId += QString(QLatin1String("%1")).arg(vendor, 4, 16, QLatin1Char('0'));
+				deviceId += QString(QLatin1String("%1")).arg(product, 4, 16, QLatin1Char('0'));
 			}
 		}
 
@@ -931,6 +1146,31 @@ void DvbLinuxDeviceManager::componentAdded(const QString &udi)
 	}
 }
 
+void DvbLinuxDeviceManager::componentRemoved(QString node, int adapter, int index) {
+        int deviceIndex = (adapter << 16) | index;
+        char adapterstring[10];
+        DvbLinuxDevice *device = devices.value(deviceIndex, NULL);
+        if (device == NULL) {
+                return;
+        }
+        sprintf(adapterstring, "adapter%d", adapter);
+        if (node == "frontend0") {
+                device->frontendPath.clear();
+        } else if (node == "dvr0") {
+                device->dvrPath.clear();
+        } else if (node == "demux0") {
+                device->demuxPath.clear();
+        } else {
+                return;
+        }
+
+	if (device->frontendPath.isEmpty() && device->dvrPath.isEmpty() &&
+            device->demuxPath.isEmpty() && device->isReady()) {
+		emit deviceRemoved(device);
+		device->stopDevice();
+	}
+}
+
 void DvbLinuxDeviceManager::componentRemoved(const QString &udi)
 {
 	DvbLinuxDevice *device = udis.take(udi);
