@@ -22,9 +22,9 @@
 #include "dvbepg_p.h"
 
 #include <QFile>
-#include <KDebug>
 #include <KStandardDirs>
 #include "../ensurenopendingoperation.h"
+#include "../log.h"
 #include "dvbdevice.h"
 #include "dvbmanager.h"
 #include "dvbsi.h"
@@ -86,10 +86,10 @@ DvbEpgModel::DvbEpgModel(DvbManager *manager_, QObject *parent) : QObject(parent
 
 	// TODO use SQL to store epg data
 
-	QFile file(KStandardDirs::locateLocal("appdata", "epgdata.dvb"));
+	QFile file(KStandardDirs::locateLocal("appdata", QLatin1String("epgdata.dvb")));
 
 	if (!file.open(QIODevice::ReadOnly)) {
-		kWarning() << "cannot open" << file.fileName();
+		Log("DvbEpgModel::DvbEpgModel: cannot open") << file.fileName();
 		return;
 	}
 
@@ -103,7 +103,7 @@ DvbEpgModel::DvbEpgModel(DvbManager *manager_, QObject *parent) : QObject(parent
 	if (version == 0x1ce0eca7) {
 		hasRecordingKey = false;
 	} else if (version != 0x79cffd36) {
-		kWarning() << "wrong version" << file.fileName();
+		Log("DvbEpgModel::DvbEpgModel: wrong version") << file.fileName();
 		return;
 	}
 
@@ -129,7 +129,7 @@ DvbEpgModel::DvbEpgModel(DvbManager *manager_, QObject *parent) : QObject(parent
 		}
 
 		if (stream.status() != QDataStream::Ok) {
-			kWarning() << "corrupt data" << file.fileName();
+			Log("DvbEpgModel::DvbEpgModel: corrupt data") << file.fileName();
 			break;
 		}
 
@@ -140,17 +140,17 @@ DvbEpgModel::DvbEpgModel(DvbManager *manager_, QObject *parent) : QObject(parent
 DvbEpgModel::~DvbEpgModel()
 {
 	if (hasPendingOperation) {
-		kWarning() << "illegal recursive call";
+		Log("DvbEpgModel::~DvbEpgModel: illegal recursive call");
 	}
 
 	if (!dvbEpgFilters.isEmpty() || !atscEpgFilters.isEmpty()) {
-		kWarning() << "filter list not empty";
+		Log("DvbEpgModel::~DvbEpgModel: filter list not empty");
 	}
 
-	QFile file(KStandardDirs::locateLocal("appdata", "epgdata.dvb"));
+	QFile file(KStandardDirs::locateLocal("appdata", QLatin1String("epgdata.dvb")));
 
 	if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
-		kWarning() << "cannot open" << file.fileName();
+		Log("DvbEpgModel::~DvbEpgModel: cannot open") << file.fileName();
 		return;
 	}
 
@@ -176,6 +176,11 @@ DvbEpgModel::~DvbEpgModel()
 	}
 }
 
+QMap<DvbSharedRecording, DvbSharedEpgEntry> DvbEpgModel::getRecordings() const
+{
+	return recordings;
+}
+
 QMap<DvbEpgEntryId, DvbSharedEpgEntry> DvbEpgModel::getEntries() const
 {
 	return entries;
@@ -212,12 +217,12 @@ QList<DvbSharedEpgEntry> DvbEpgModel::getCurrentNext(const DvbSharedChannel &cha
 DvbSharedEpgEntry DvbEpgModel::addEntry(const DvbEpgEntry &entry)
 {
 	if (!entry.validate()) {
-		kWarning() << "invalid entry";
+		Log("DvbEpgModel::addEntry: invalid entry");
 		return DvbSharedEpgEntry();
 	}
 
 	if (hasPendingOperation) {
-		kWarning() << "illegal recursive call";
+		Log("DvbEpgModel::addEntry: illegal recursive call");
 		return DvbSharedEpgEntry();
 	}
 
@@ -257,15 +262,15 @@ DvbSharedEpgEntry DvbEpgModel::addEntry(const DvbEpgEntry &entry)
 }
 
 void DvbEpgModel::scheduleProgram(const DvbSharedEpgEntry &entry, int extraSecondsBefore,
-	int extraSecondsAfter)
+	int extraSecondsAfter, bool checkForRecursion)
 {
 	if (!entry.isValid() || (entries.value(DvbEpgEntryId(entry)) != entry)) {
-		kWarning() << "invalid entry";
+		Log("DvbEpgModel::scheduleProgram: invalid entry");
 		return;
 	}
 
 	if (hasPendingOperation) {
-		kWarning() << "illegal recursive call";
+		Log("DvbEpgModel::scheduleProgram: illegal recursive call");
 		return;
 	}
 
@@ -278,10 +283,17 @@ void DvbEpgModel::scheduleProgram(const DvbSharedEpgEntry &entry, int extraSecon
 		recording.name = entry->title;
 		recording.channel = entry->channel;
 		recording.begin = entry->begin.addSecs(-extraSecondsBefore);
+		recording.beginEPG = entry->begin;
 		recording.duration =
 			entry->duration.addSecs(extraSecondsBefore + extraSecondsAfter);
+		recording.durationEPG =
+			entry->duration;
+		recording.subheading =
+			entry->subheading;
+		recording.details =
+			entry->details;
 		const_cast<DvbEpgEntry *>(entry.constData())->recording =
-			manager->getRecordingModel()->addRecording(recording);
+			manager->getRecordingModel()->addRecording(recording, checkForRecursion);
 		recordings.insert(entry->recording, entry);
 	} else {
 		oldRecording = entry->recording;
@@ -362,7 +374,7 @@ void DvbEpgModel::channelAboutToBeUpdated(const DvbSharedChannel &channel)
 void DvbEpgModel::channelUpdated(const DvbSharedChannel &channel)
 {
 	if (hasPendingOperation) {
-		kWarning() << "illegal recursive call";
+		Log("DvbEpgModel::channelUpdated: illegal recursive call");
 		return;
 	}
 
@@ -381,7 +393,7 @@ void DvbEpgModel::channelUpdated(const DvbSharedChannel &channel)
 void DvbEpgModel::channelRemoved(const DvbSharedChannel &channel)
 {
 	if (hasPendingOperation) {
-		kWarning() << "illegal recursive call";
+		Log("DvbEpgModel::channelRemoved: illegal recursive call");
 		return;
 	}
 
@@ -397,7 +409,7 @@ void DvbEpgModel::channelRemoved(const DvbSharedChannel &channel)
 void DvbEpgModel::recordingRemoved(const DvbSharedRecording &recording)
 {
 	if (hasPendingOperation) {
-		kWarning() << "illegal recursive call";
+		Log("DvbEpgModel::recordingRemoved: illegal recursive call");
 		return;
 	}
 
@@ -416,7 +428,7 @@ void DvbEpgModel::timerEvent(QTimerEvent *event)
 	Q_UNUSED(event)
 
 	if (hasPendingOperation) {
-		kWarning() << "illegal recursive call";
+		Log("DvbEpgModel::timerEvent: illegal recursive call");
 		return;
 	}
 
@@ -690,15 +702,15 @@ void AtscEpgFilter::processEitSection(const char *data, int size)
 	// 1980-01-06T000000 minus 15 secs (= UTC - GPS in 2011)
 	QDateTime baseDateTime = QDateTime(QDate(1980, 1, 5), QTime(23, 59, 45), Qt::UTC);
 
-	for (AtscEitSectionEntry entry = eitSection.entries(); (entryCount > 0) && entry.isValid();
-	     --entryCount, entry.advance()) {
+	for (AtscEitSectionEntry eitEntry = eitSection.entries();
+	     (entryCount > 0) && eitEntry.isValid(); --entryCount, eitEntry.advance()) {
 		DvbEpgEntry epgEntry;
 		epgEntry.channel = channel;
-		epgEntry.begin = baseDateTime.addSecs(entry.startTime());
-		epgEntry.duration = QTime().addSecs(entry.duration());
-		epgEntry.title = entry.title();
+		epgEntry.begin = baseDateTime.addSecs(eitEntry.startTime());
+		epgEntry.duration = QTime().addSecs(eitEntry.duration());
+		epgEntry.title = eitEntry.title();
 
-		quint32 id = ((quint32(fakeChannel.networkId) << 16) | quint32(entry.eventId()));
+		quint32 id = ((quint32(fakeChannel.networkId) << 16) | quint32(eitEntry.eventId()));
 		DvbSharedEpgEntry entry = epgEntries.value(id);
 
 		if (entry.isValid() && (entry->channel == epgEntry.channel) &&
