@@ -1,7 +1,7 @@
 /*
  * dvbmanager.cpp
  *
- * Copyright (C) 2008-2010 Christoph Pfister <christophpfister@gmail.com>
+ * Copyright (C) 2008-2011 Christoph Pfister <christophpfister@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,12 +23,11 @@
 
 #include <QDir>
 #include <QPluginLoader>
-#include <QWidget>
 #include <KConfigGroup>
-#include <KDebug>
 #include <KLocale>
 #include <KStandardDirs>
 #include <config-kaffeine.h>
+#include "../log.h"
 #include "dvbconfig.h"
 #include "dvbdevice.h"
 #include "dvbdevice_linux.h"
@@ -268,7 +267,7 @@ QString DvbManager::getAutoScanSource(const QString &source) const
 	QPair<TransmissionType, QString> scanSource = sourceMapping.value(source);
 
 	if (scanSource.second.isEmpty()) {
-		kWarning() << "invalid source";
+		Log("DvbManager::getAutoScanSource: invalid source");
 		return QString();
 	}
 
@@ -288,7 +287,7 @@ QList<DvbTransponder> DvbManager::getTransponders(DvbDevice *device, const QStri
 	QPair<TransmissionType, QString> scanSource = sourceMapping.value(source);
 
 	if (scanSource.second.isEmpty()) {
-		kWarning() << "invalid source";
+		Log("DvbManager::getTransponders: invalid source");
 		return QList<DvbTransponder>();
 	}
 
@@ -305,19 +304,19 @@ bool DvbManager::updateScanData(const QByteArray &data)
 	QByteArray uncompressed = qUncompress(data);
 
 	if (uncompressed.isEmpty()) {
-		kWarning() << "qUncompress failed";
+		Log("DvbManager::updateScanData: qUncompress failed");
 		return false;
 	}
 
 	if (!DvbScanData(uncompressed).readDate().isValid()) {
-		kWarning() << "invalid format";
+		Log("DvbManager::updateScanData: invalid format");
 		return false;
 	}
 
-	QFile file(KStandardDirs::locateLocal("appdata", "scanfile.dvb"));
+	QFile file(KStandardDirs::locateLocal("appdata", QLatin1String("scanfile.dvb")));
 
 	if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
-		kWarning() << "can't open" << file.fileName();
+		Log("DvbManager::updateScanData: cannot open") << file.fileName();
 		return false;
 	}
 
@@ -348,11 +347,31 @@ int DvbManager::getEndMargin() const
 	return KGlobal::config()->group("DVB").readEntry("EndMargin", 600);
 }
 
+QString DvbManager::getNamingFormat() const
+{
+	return KGlobal::config()->group("DVB").readEntry("NamingFormat", "%title");
+}
+
+QString DvbManager::getRecordingRegex() const
+{
+	return KGlobal::config()->group("DVB").readEntry("RecordingRegex", "");
+}
+
+QString DvbManager::getActionAfterRecording() const
+{
+	return KGlobal::config()->group("DVB").readEntry("ActionAfterRecording", "");
+}
+
 bool DvbManager::override6937Charset() const
 {
 	return KGlobal::config()->group("DVB").readEntry("Override6937", false);
 }
 
+bool DvbManager::createInfoFile() const
+{
+	return KGlobal::config()->group("DVB").readEntry("CreateInfoFile", false);
+}
+
 void DvbManager::setRecordingFolder(const QString &path)
 {
 	KGlobal::config()->group("DVB").writeEntry("RecordingFolder", path);
@@ -373,12 +392,32 @@ void DvbManager::setEndMargin(int endMargin)
 	KGlobal::config()->group("DVB").writeEntry("EndMargin", endMargin);
 }
 
+void DvbManager::setNamingFormat(QString namingFormat)
+{
+	KGlobal::config()->group("DVB").writeEntry("NamingFormat", namingFormat);
+}
+
+void DvbManager::setRecordingRegex(QString regex)
+{
+	KGlobal::config()->group("DVB").writeEntry("RecordingRegex", regex);
+}
+
+void DvbManager::setActionAfterRecording(QString actionAfterRecording)
+{
+	KGlobal::config()->group("DVB").writeEntry("ActionAfterRecording", actionAfterRecording);
+}
+
 void DvbManager::setOverride6937Charset(bool override)
 {
 	KGlobal::config()->group("DVB").writeEntry("Override6937", override);
 	DvbSiText::setOverride6937(override);
 }
 
+void DvbManager::setCreateInfoFile(bool createInfoFile)
+{
+	KGlobal::config()->group("DVB").writeEntry("CreateInfoFile", createInfoFile);
+}
+
 double DvbManager::getLatitude()
 {
 	return KGlobal::config()->group("DVB").readEntry("Latitude", 0.0);
@@ -448,15 +487,17 @@ void DvbManager::deviceAdded(DvbBackendDevice *backendDevice)
 void DvbManager::deviceRemoved(DvbBackendDevice *backendDevice)
 {
 	for (int i = 0; i < deviceConfigs.size(); ++i) {
-		if (deviceConfigs.at(i).device->getBackendDevice() == backendDevice) {
-			if (deviceConfigs[i].useCount != 0) {
-				deviceConfigs[i].useCount = 0;
-				deviceConfigs[i].prioritizedUseCount = 0;
-				deviceConfigs[i].device->release();
+		DvbDeviceConfig &it = deviceConfigs[i];
+
+		if (it.device && it.device->getBackendDevice() == backendDevice) {
+			if (it.useCount != 0) {
+				it.useCount = 0;
+				it.prioritizedUseCount = 0;
+				it.device->release();
 			}
 
-			delete deviceConfigs[i].device;
-			deviceConfigs[i].device = NULL;
+			delete it.device;
+			it.device = NULL;
 			break;
 		}
 	}
@@ -465,7 +506,7 @@ void DvbManager::deviceRemoved(DvbBackendDevice *backendDevice)
 void DvbManager::loadDeviceManager()
 {
 	QDir dir(QString::fromUtf8(KAFFEINE_LIB_INSTALL_DIR "/"));
-	QStringList entries = dir.entryList(QStringList("*kaffeinedvb*"), QDir::NoFilter,
+	QStringList entries = dir.entryList(QStringList(QLatin1String("*kaffeinedvb*")), QDir::NoFilter,
 		QDir::Name | QDir::Reversed);
 
 	foreach (const QString &entry, entries) {
@@ -478,11 +519,12 @@ void DvbManager::loadDeviceManager()
 		QObject *deviceManager = QPluginLoader(path).instance();
 
 		if (deviceManager == NULL) {
-			kWarning() << "cannot load dvb device manager" << path;
+			Log("DvbManager::loadDeviceManager: cannot load dvb device manager") <<
+				path;
 			break;
 		}
 
-		kDebug() << "using dvb device manager" << path;
+		Log("DvbManager::loadDeviceManager: using dvb device manager") << path;
 		deviceManager->setParent(this);
 		connect(deviceManager, SIGNAL(requestBuiltinDeviceManager(QObject*&)),
 			this, SLOT(requestBuiltinDeviceManager(QObject*&)));
@@ -494,7 +536,7 @@ void DvbManager::loadDeviceManager()
 		return;
 	}
 
-	kDebug() << "using built-in dvb device manager";
+	Log("DvbManager::loadDeviceManager: using built-in dvb device manager");
 	DvbLinuxDeviceManager *deviceManager = new DvbLinuxDeviceManager(this);
 	connect(deviceManager, SIGNAL(deviceAdded(DvbBackendDevice*)),
 		this, SLOT(deviceAdded(DvbBackendDevice*)));
@@ -505,23 +547,23 @@ void DvbManager::loadDeviceManager()
 
 void DvbManager::readDeviceConfigs()
 {
-	QFile file(KStandardDirs::locateLocal("appdata", "config.dvb"));
+	QFile file(KStandardDirs::locateLocal("appdata", QLatin1String("config.dvb")));
 
 	if (!file.open(QIODevice::ReadOnly)) {
-		kWarning() << "can't open" << file.fileName();
+		Log("DvbManager::readDeviceConfigs: cannot open") << file.fileName();
 		return;
 	}
 
 	DvbDeviceConfigReader reader(&file);
 
 	while (!reader.atEnd()) {
-		if (reader.readLine() != "[device]") {
+		if (reader.readLine() != QLatin1String("[device]")) {
 			continue;
 		}
 
-		QString deviceId = reader.readString("deviceId");
-		QString frontendName = reader.readString("frontendName");
-		int configCount = reader.readInt("configCount");
+		QString deviceId = reader.readString(QLatin1String("deviceId"));
+		QString frontendName = reader.readString(QLatin1String("frontendName"));
+		int configCount = reader.readInt(QLatin1String("configCount"));
 
 		if (!reader.isValid()) {
 			break;
@@ -531,30 +573,30 @@ void DvbManager::readDeviceConfigs()
 
 		for (int i = 0; i < configCount; ++i) {
 			while (!reader.atEnd()) {
-				if (reader.readLine() == "[config]") {
+				if (reader.readLine() == QLatin1String("[config]")) {
 					break;
 				}
 			}
 
 			DvbConfigBase::TransmissionType type =
-				reader.readEnum("type", DvbConfigBase::TransmissionTypeMax);
+				reader.readEnum(QLatin1String("type"), DvbConfigBase::TransmissionTypeMax);
 
 			if (!reader.isValid()) {
 				break;
 			}
 
 			DvbConfigBase *config = new DvbConfigBase(type);
-			config->name = reader.readString("name");
-			config->scanSource = reader.readString("scanSource");
-			config->timeout = reader.readInt("timeout");
+			config->name = reader.readString(QLatin1String("name"));
+			config->scanSource = reader.readString(QLatin1String("scanSource"));
+			config->timeout = reader.readInt(QLatin1String("timeout"));
 
 			if (type == DvbConfigBase::DvbS) {
-				config->configuration = reader.readEnum("configuration",
+				config->configuration = reader.readEnum(QLatin1String("configuration"),
 					DvbConfigBase::ConfigurationMax);
-				config->lnbNumber = reader.readInt("lnbNumber");
-				config->lowBandFrequency = reader.readInt("lowBandFrequency");
-				config->switchFrequency = reader.readInt("switchFrequency");
-				config->highBandFrequency = reader.readInt("highBandFrequency");
+				config->lnbNumber = reader.readInt(QLatin1String("lnbNumber"));
+				config->lowBandFrequency = reader.readInt(QLatin1String("lowBandFrequency"));
+				config->switchFrequency = reader.readInt(QLatin1String("switchFrequency"));
+				config->highBandFrequency = reader.readInt(QLatin1String("highBandFrequency"));
 			}
 
 			if (!reader.isValid()) {
@@ -569,40 +611,41 @@ void DvbManager::readDeviceConfigs()
 	}
 
 	if (!reader.isValid()) {
-		kWarning() << "can't read" << file.fileName();
+		Log("DvbManager::readDeviceConfigs: cannot read") << file.fileName();
 	}
 }
 
 void DvbManager::writeDeviceConfigs()
 {
-	QFile file(KStandardDirs::locateLocal("appdata", "config.dvb"));
+	QFile file(KStandardDirs::locateLocal("appdata", QLatin1String("config.dvb")));
 
 	if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
-		kWarning() << "can't open" << file.fileName();
+		Log("DvbManager::writeDeviceConfigs: cannot open") << file.fileName();
 		return;
 	}
 
 	DvbDeviceConfigWriter writer(&file);
 
 	foreach (const DvbDeviceConfig &deviceConfig, deviceConfigs) {
-		writer.write("[device]");
-		writer.write("deviceId", deviceConfig.deviceId);
-		writer.write("frontendName", deviceConfig.frontendName);
-		writer.write("configCount", deviceConfig.configs.size());
+		writer.write(QLatin1String("[device]"));
+		writer.write(QLatin1String("deviceId"), deviceConfig.deviceId);
+		writer.write(QLatin1String("frontendName"), deviceConfig.frontendName);
+		writer.write(QLatin1String("configCount"), deviceConfig.configs.size());
 
-		foreach (const DvbConfig &config, deviceConfig.configs) {
-			writer.write("[config]");
-			writer.write("type", config->getTransmissionType());
-			writer.write("name", config->name);
-			writer.write("scanSource", config->scanSource);
-			writer.write("timeout", config->timeout);
+		for (int i = 0; i < deviceConfig.configs.size(); ++i) {
+			const DvbConfig &config = deviceConfig.configs.at(i);
+			writer.write(QLatin1String("[config]"));
+			writer.write(QLatin1String("type"), config->getTransmissionType());
+			writer.write(QLatin1String("name"), config->name);
+			writer.write(QLatin1String("scanSource"), config->scanSource);
+			writer.write(QLatin1String("timeout"), config->timeout);
 
 			if (config->getTransmissionType() == DvbConfigBase::DvbS) {
-				writer.write("configuration", config->configuration);
-				writer.write("lnbNumber", config->lnbNumber);
-				writer.write("lowBandFrequency", config->lowBandFrequency);
-				writer.write("switchFrequency", config->switchFrequency);
-				writer.write("highBandFrequency", config->highBandFrequency);
+				writer.write(QLatin1String("configuration"), config->configuration);
+				writer.write(QLatin1String("lnbNumber"), config->lnbNumber);
+				writer.write(QLatin1String("lowBandFrequency"), config->lowBandFrequency);
+				writer.write(QLatin1String("switchFrequency"), config->switchFrequency);
+				writer.write(QLatin1String("highBandFrequency"), config->highBandFrequency);
 			}
 		}
 	}
@@ -613,7 +656,8 @@ void DvbManager::updateSourceMapping()
 	sourceMapping.clear();
 
 	foreach (const DvbDeviceConfig &deviceConfig, deviceConfigs) {
-		foreach (const DvbConfig &config, deviceConfig.configs) {
+		for (int i = 0; i < deviceConfig.configs.size(); ++i) {
+			const DvbConfig &config = deviceConfig.configs.at(i);
 			TransmissionType type;
 
 			switch (config->getTransmissionType()) {
@@ -653,15 +697,15 @@ void DvbManager::readScanData()
 		globalDate = DvbScanData(globalFile.read(1024)).readDate();
 
 		if (globalDate.isNull()) {
-			kWarning() << "cannot parse" << globalFile.fileName();
+			Log("DvbManager::readScanData: cannot parse") << globalFile.fileName();
 		}
 
 		globalFile.close();
 	} else {
-		kWarning() << "cannot open" << globalFile.fileName();
+		Log("DvbManager::readScanData: cannot open") << globalFile.fileName();
 	}
 
-	QFile localFile(KStandardDirs::locateLocal("appdata", "scanfile.dvb"));
+	QFile localFile(KStandardDirs::locateLocal("appdata", QLatin1String("scanfile.dvb")));
 	QByteArray localData;
 	QDate localDate;
 
@@ -670,7 +714,7 @@ void DvbManager::readScanData()
 		localDate = DvbScanData(localData).readDate();
 
 		if (localDate.isNull()) {
-			kWarning() << "cannot parse" << localFile.fileName();
+			Log("DvbManager::readScanData: cannot parse") << localFile.fileName();
 		}
 
 		localFile.close();
@@ -680,19 +724,19 @@ void DvbManager::readScanData()
 		localData.clear();
 
 		if (localFile.exists() && !localFile.remove()) {
-			kWarning() << "cannot remove" << localFile.fileName();
+			Log("DvbManager::readScanData: cannot remove") << localFile.fileName();
 		}
 
 		if (!globalFile.copy(localFile.fileName())) {
-			kWarning() << "cannot copy" << globalFile.fileName() << "to" <<
-				localFile.fileName();
+			Log("DvbManager::readScanData: cannot copy") << globalFile.fileName() <<
+				QLatin1String("to") << localFile.fileName();
 		}
 
 		if (localFile.open(QIODevice::ReadOnly)) {
 			localData = localFile.readAll();
 			localFile.close();
 		} else {
-			kWarning() << "cannot open" << localFile.fileName();
+			Log("DvbManager::readScanData: cannot open") << localFile.fileName();
 			scanDataDate = QDate(1900, 1, 1);
 			return;
 		}
@@ -702,7 +746,7 @@ void DvbManager::readScanData()
 	scanDataDate = data.readDate();
 
 	if (!scanDataDate.isValid()) {
-		kWarning() << "cannot parse" << localFile.fileName();
+		Log("DvbManager::readScanData: cannot parse") << localFile.fileName();
 		scanDataDate = QDate(1900, 1, 1);
 		return;
 	}
@@ -712,21 +756,21 @@ void DvbManager::readScanData()
 	    !readScanSources(data, "[dvb-t/", DvbT) ||
 	    !readScanSources(data, "[atsc/", Atsc) ||
 	    !data.checkEnd()) {
-		kWarning() << "cannot parse" << localFile.fileName();
+		Log("DvbManager::readScanData: cannot parse") << localFile.fileName();
 	}
 }
 
 bool DvbManager::readScanSources(DvbScanData &data, const char *tag, TransmissionType type)
 {
-	int tagLen = strlen(tag);
+	int tagLen = int(strlen(tag));
 	bool parseError = false;
 
 	while (strncmp(data.getLine(), tag, tagLen) == 0) {
 		const char *line = data.readLine();
 
-		QString name = QString(line + tagLen);
+		QString name = QString(QLatin1String(line)).remove(0, tagLen);
 
-		if ((name.size() < 2) || (name.at(name.size() - 1) != ']')) {
+		if ((name.size() < 2) || (name.at(name.size() - 1) != QLatin1Char(']'))) {
 			return false;
 		}
 
@@ -780,7 +824,7 @@ bool DvbManager::readScanSources(DvbScanData &data, const char *tag, Transmissio
 	}
 
 	if (parseError) {
-		kWarning() << "can't parse complete scan data";
+		Log("DvbManager::readScanSources: cannot parse complete scan data");
 	}
 
 	return true;
