@@ -22,12 +22,16 @@
 #include "dvbrecording_p.h"
 
 #include <QDir>
+#include <QMap>
+#include <QProcess>
+#include <QSet>
 #include <QVariant>
-#include <KDebug>
 #include <KStandardDirs>
 #include "../ensurenopendingoperation.h"
+#include "../log.h"
 #include "dvbdevice.h"
 #include "dvbmanager.h"
+#include "dvbepg.h"
 
 bool DvbRecording::validate()
 {
@@ -36,6 +40,8 @@ bool DvbRecording::validate()
 		// the seconds and milliseconds aren't visible --> set them to zero
 		begin = begin.addMSecs(-(QTime().msecsTo(begin.time()) % 60000));
 		end = begin.addSecs(QTime().secsTo(duration));
+		beginEPG = beginEPG.addMSecs(-(QTime().msecsTo(beginEPG.time()) % 60000));
+		endEPG = beginEPG.addSecs(QTime().secsTo(durationEPG));
 		repeat &= ((1 << 7) - 1);
 		return true;
 	}
@@ -46,8 +52,10 @@ bool DvbRecording::validate()
 DvbRecordingModel::DvbRecordingModel(DvbManager *manager_, QObject *parent) : QObject(parent),
 	manager(manager_), hasPendingOperation(false)
 {
-	sqlInit("RecordingSchedule",
-		QStringList() << "Name" << "Channel" << "Begin" << "Duration" << "Repeat");
+	sqlInit(QLatin1String("RecordingSchedule"),
+		QStringList() << QLatin1String("Name") << QLatin1String("Channel") << QLatin1String("Begin") <<
+		QLatin1String("Duration") << QLatin1String("Repeat") << QLatin1String("Subheading") << QLatin1String("Details")
+		<< QLatin1String("beginEPG") << QLatin1String("endEPG") << QLatin1String("durationEPG"));
 
 	// we regularly recheck the status of the recordings
 	// this way we can keep retrying if the device was busy / tuning failed
@@ -56,14 +64,14 @@ DvbRecordingModel::DvbRecordingModel(DvbManager *manager_, QObject *parent) : QO
 
 	// compatibility code
 
-	QFile file(KStandardDirs::locateLocal("appdata", "recordings.dvb"));
+	QFile file(KStandardDirs::locateLocal("appdata", QLatin1String("recordings.dvb")));
 
 	if (!file.exists()) {
 		return;
 	}
 
 	if (!file.open(QIODevice::ReadOnly)) {
-		kWarning() << "cannot open file" << file.fileName();
+		Log("DvbRecordingModel::DvbRecordingModel: cannot open file") << file.fileName();
 		return;
 	}
 
@@ -84,9 +92,11 @@ DvbRecordingModel::DvbRecordingModel(DvbManager *manager_, QObject *parent) : QO
 		QString channelName;
 		stream >> channelName;
 		recording.channel = channelModel->findChannelByName(channelName);
-		stream >> recording.begin;
-		recording.begin = recording.begin.toUTC();
+		stream >> recording.beginEPG;
+		recording.begin = recording.beginEPG.toUTC();
+		recording.beginEPG = recording.beginEPG.toLocalTime();
 		stream >> recording.duration;
+		recording.durationEPG = recording.duration;
 		QDateTime end;
 		stream >> end;
 
@@ -94,8 +104,12 @@ DvbRecordingModel::DvbRecordingModel(DvbManager *manager_, QObject *parent) : QO
 			stream >> recording.repeat;
 		}
 
+		stream >> recording.subheading;
+		stream >> recording.details;
+
 		if (stream.status() != QDataStream::Ok) {
-			kWarning() << "invalid recordings in file" << file.fileName();
+			Log("DvbRecordingModel::DvbRecordingModel: invalid recordings in file") <<
+				file.fileName();
 			break;
 		}
 
@@ -103,14 +117,14 @@ DvbRecordingModel::DvbRecordingModel(DvbManager *manager_, QObject *parent) : QO
 	}
 
 	if (!file.remove()) {
-		kWarning() << "cannot remove file" << file.fileName();
+		Log("DvbRecordingModel::DvbRecordingModel: cannot remove file") << file.fileName();
 	}
 }
 
 DvbRecordingModel::~DvbRecordingModel()
 {
 	if (hasPendingOperation) {
-		kWarning() << "illegal recursive call";
+		Log("DvbRecordingModel::~DvbRecordingModel: illegal recursive call");
 	}
 
 	sqlFlush();
@@ -131,22 +145,34 @@ DvbSharedRecording DvbRecordingModel::findRecordingByKey(const SqlKey &sqlKey) c
 	return recordings.value(sqlKey);
 }
 
+DvbRecording DvbRecordingModel::getCurrentRecording()
+{
+	return currentRecording;
+}
+
+void DvbRecordingModel::setCurrentRecording(DvbRecording _currentRecording)
+{
+	currentRecording = _currentRecording;
+}
+
 QMap<SqlKey, DvbSharedRecording> DvbRecordingModel::getRecordings() const
 {
 	return recordings;
 }
 
-DvbSharedRecording DvbRecordingModel::addRecording(DvbRecording &recording)
+DvbSharedRecording DvbRecordingModel::addRecording(DvbRecording &recording, bool checkForRecursion)
 {
-	if (hasPendingOperation) {
-		kWarning() << "illegal recursive call";
-		return DvbSharedRecording();
+	if (checkForRecursion) {
+		if (hasPendingOperation) {
+			Log("DvbRecordingModel::addRecording: illegal recursive call");
+			return DvbSharedRecording();
+		}
+
+		EnsureNoPendingOperation ensureNoPendingOperation(hasPendingOperation);
 	}
 
-	EnsureNoPendingOperation ensureNoPendingOperation(hasPendingOperation);
-
 	if (!recording.validate()) {
-		kWarning() << "invalid recording";
+		Log("DvbRecordingModel::addRecording: invalid recording");
 		return DvbSharedRecording();
 	}
 
@@ -167,7 +193,7 @@ void DvbRecordingModel::updateRecording(DvbSharedRecording recording,
 	DvbRecording &modifiedRecording)
 {
 	if (hasPendingOperation) {
-		kWarning() << "illegal recursive call";
+		Log("DvbRecordingModel::updateRecording: illegal recursive call");
 		return;
 	}
 
@@ -175,7 +201,7 @@ void DvbRecordingModel::updateRecording(DvbSharedRecording recording,
 
 	if (!recording.isValid() || (recordings.value(*recording) != recording) ||
 	    !modifiedRecording.validate()) {
-		kWarning() << "invalid recording";
+		Log("DvbRecordingModel::updateRecording: invalid recording");
 		return;
 	}
 
@@ -198,14 +224,14 @@ void DvbRecordingModel::updateRecording(DvbSharedRecording recording,
 void DvbRecordingModel::removeRecording(DvbSharedRecording recording)
 {
 	if (hasPendingOperation) {
-		kWarning() << "illegal recursive call";
+		Log("DvbRecordingModel::removeRecording: illegal recursive call");
 		return;
 	}
 
 	EnsureNoPendingOperation ensureNoPendingOperation(hasPendingOperation);
 
 	if (!recording.isValid() || (recordings.value(*recording) != recording)) {
-		kWarning() << "invalid recording";
+		Log("DvbRecordingModel::removeRecording: invalid recording");
 		return;
 	}
 
@@ -213,6 +239,70 @@ void DvbRecordingModel::removeRecording(DvbSharedRecording recording)
 	recordingFiles.remove(*recording);
 	sqlRemove(*recording);
 	emit recordingRemoved(recording);
+	executeActionAfterRecording(*recording);
+	findNewRecordings();
+}
+
+void DvbRecordingModel::executeActionAfterRecording(DvbRecording recording)
+{
+	QString stopCommand = manager->getActionAfterRecording();
+
+	stopCommand.replace("%filename", recording.filename);
+	if (!stopCommand.isEmpty())
+	{
+		QProcess* child = new QProcess();
+		child->start(stopCommand);
+		Log("DvbRecordingModel::shutdownWhenEmpty:could not execute cmd");
+	}
+	Log("DvbRecordingModel::executeActionAfterRecording executed.");
+
+
+}
+
+bool DvbRecordingModel::existsSimilarRecording(DvbEpgEntry recording)
+{
+	bool found = false;
+
+	DvbEpgEntry entry = recording;
+	DvbEpgModel *epgModel = manager->getEpgModel();
+	QMap<DvbSharedRecording, DvbSharedEpgEntry> recordingMap = epgModel->getRecordings();
+	foreach(DvbSharedRecording key, recordingMap.keys())
+	{
+		DvbEpgEntry loopEntry = *(recordingMap.value(key));
+		if (entry.begin == loopEntry.begin
+				&& entry.channel == loopEntry.channel
+				&& entry.duration == loopEntry.duration) {
+			found = true;
+			break;
+		}
+	}
+	return found;
+}
+
+void DvbRecordingModel::findNewRecordings()
+{
+	DvbEpgModel *epgModel = manager->getEpgModel();
+	QMap<DvbEpgEntryId, DvbSharedEpgEntry> epgMap = epgModel->getEntries();
+	foreach(DvbEpgEntryId key, epgMap.keys())
+	{
+		DvbEpgEntry entry = *(epgMap.value(key));
+		QString title = entry.title;
+		QRegExp recordingRegex = QRegExp(manager->getRecordingRegex());
+		if (!recordingRegex.isEmpty())
+			{
+			if (recordingRegex.indexIn(title) != -1)
+			{
+				if (!DvbRecordingModel::existsSimilarRecording(*epgMap.value(key)))
+				{
+				epgModel->scheduleProgram(epgMap.value(key), manager->getBeginMargin(),
+						manager->getEndMargin(), false);
+				Log("DvbRecordingModel::findNewRecordings: scheduled") << title;
+				}
+			}
+		}
+	}
+
+	Log("DvbRecordingModel::findNewRecordings executed.");
 }
 
 void DvbRecordingModel::timerEvent(QTimerEvent *event)
@@ -241,15 +331,20 @@ void DvbRecordingModel::bindToSqlQuery(SqlKey sqlKey, QSqlQuery &query, int inde
 	DvbSharedRecording recording = recordings.value(sqlKey);
 
 	if (!recording.isValid()) {
-		kError() << "invalid recording";
+		Log("DvbRecordingModel::bindToSqlQuery: invalid recording");
 		return;
 	}
 
 	query.bindValue(index++, recording->name);
 	query.bindValue(index++, recording->channel->name);
-	query.bindValue(index++, recording->begin.toString(Qt::ISODate) + 'Z');
+	query.bindValue(index++, recording->begin.toString(Qt::ISODate) + QLatin1Char('Z'));
 	query.bindValue(index++, recording->duration.toString(Qt::ISODate));
 	query.bindValue(index++, recording->repeat);
+	query.bindValue(index++, recording->subheading);
+	query.bindValue(index++, recording->details);
+	query.bindValue(index++, recording->beginEPG.toString(Qt::ISODate));
+	query.bindValue(index++, recording->endEPG.toString(Qt::ISODate));
+	query.bindValue(index++, recording->durationEPG.toString(Qt::ISODate));
 }
 
 bool DvbRecordingModel::insertFromSqlQuery(SqlKey sqlKey, const QSqlQuery &query, int index)
@@ -263,6 +358,13 @@ bool DvbRecordingModel::insertFromSqlQuery(SqlKey sqlKey, const QSqlQuery &query
 		QDateTime::fromString(query.value(index++).toString(), Qt::ISODate).toUTC();
 	recording->duration = QTime::fromString(query.value(index++).toString(), Qt::ISODate);
 	recording->repeat = query.value(index++).toInt();
+	recording->subheading = query.value(index++).toString();
+	recording->details = query.value(index++).toString();
+	recording->beginEPG =
+		QDateTime::fromString(query.value(index++).toString(), Qt::ISODate).toLocalTime();
+	recording->endEPG =
+		QDateTime::fromString(query.value(index++).toString(), Qt::ISODate).toLocalTime();
+	recording->durationEPG = QTime::fromString(query.value(index++).toString(), Qt::ISODate);
 
 	if (recording->validate()) {
 		recording->setSqlKey(sqlKey);
@@ -345,17 +447,39 @@ DvbRecordingFile::~DvbRecordingFile()
 	stop();
 }
 
-bool DvbRecordingFile::start(const DvbRecording &recording)
+bool DvbRecordingFile::start(DvbRecording &recording)
 {
 	if (!file.isOpen()) {
 		QString folder = manager->getRecordingFolder();
-		QString path = folder + '/' + QString(recording.name).replace('/', '_');
+		QDate currentDate = QDate::currentDate();
+		QTime currentTime = QTime::currentTime();
+
+		QString filename = manager->getNamingFormat();
+		filename = filename.replace("%year", currentDate.toString("yyyy"));
+		filename = filename.replace("%month", currentDate.toString("MM"));
+		filename = filename.replace("%day", currentDate.toString("dd"));
+		filename = filename.replace("%hour", currentTime.toString("hh"));
+		filename = filename.replace("%min", currentTime.toString("mm"));
+		filename = filename.replace("%sec", currentTime.toString("ss"));
+		filename = filename.replace("%channel", recording.channel->name);
+		filename = filename.replace("%title", QString(recording.name));
+		filename = filename.replace(QLatin1Char('/'), QLatin1Char('_'));
+		if (filename == "") {
+			filename = QString(recording.name);
+		}
+
+		QString path = folder + QLatin1Char('/') + filename;
+
 
 		for (int attempt = 0; attempt < 100; ++attempt) {
 			if (attempt == 0) {
-				file.setFileName(path + ".m2t");
+				file.setFileName(path + QLatin1String(".m2t"));
+				recording.filename = filename + QLatin1String(".m2t");
 			} else {
-				file.setFileName(path + '-' + QString::number(attempt) + ".m2t");
+				file.setFileName(path + QLatin1Char('-') + QString::number(attempt) +
+					QLatin1String(".m2t"));
+				recording.filename = filename + QLatin1Char('-') + QString::number(attempt) +
+					QLatin1String(".m2t");
 			}
 
 			if (file.exists()) {
@@ -365,7 +489,8 @@ bool DvbRecordingFile::start(const DvbRecording &recording)
 			if (file.open(QIODevice::WriteOnly)) {
 				break;
 			} else {
-				kWarning() << "cannot open file" << file.fileName();
+				Log("DvbRecordingFile::start: cannot open file") <<
+					file.fileName();
 			}
 
 			if ((attempt == 0) && !QDir(folder).exists()) {
@@ -373,13 +498,15 @@ bool DvbRecordingFile::start(const DvbRecording &recording)
 					attempt = -1;
 					continue;
 				} else {
-					kWarning() << "cannot create folder" << folder;
+					Log("DvbRecordingFile::start: cannot create folder") <<
+						folder;
 				}
 			}
 
 			if (folder != QDir::homePath()) {
 				folder = QDir::homePath();
-				path = folder + '/' + QString(recording.name).replace('/', '_');
+				path = folder + QLatin1Char('/') +
+					QString(recording.name).replace(QLatin1Char('/'), QLatin1Char('_'));
 				attempt = -1;
 				continue;
 			}
@@ -387,8 +514,25 @@ bool DvbRecordingFile::start(const DvbRecording &recording)
 			break;
 		}
 
+		if (manager->createInfoFile()) {
+			QString infoFile = path + ".txt";
+			QFile file(infoFile);
+			if (file.open(QIODevice::ReadWrite))
+			{
+			    QTextStream stream(&file);
+			    stream << "EPG info" << endl;
+			    stream << "Title: " + QString(recording.name) << endl;
+			    stream << "Description: " + QString(recording.subheading) << endl;
+			    //stream << "Details: " + QString(recording.details) << endl; // Details is almost always empty
+			    stream << "Channel: " + QString(recording.channel->name) << endl;
+			    stream << "Date: " + recording.beginEPG.toLocalTime().toString("yyyy-MM-dd") << endl;
+			    stream << "Start time: " + recording.beginEPG.toLocalTime().toString("hh:mm:ss") << endl;
+			    stream << "Duration: " + recording.durationEPG.toString("HH:mm:ss") << endl;
+			}
+		}
+
 		if (!file.isOpen()) {
-			kWarning() << "cannot open file" << file.fileName();
+			Log("DvbRecordingFile::start: cannot open file") << file.fileName();
 			return false;
 		}
 	}
@@ -399,7 +543,7 @@ bool DvbRecordingFile::start(const DvbRecording &recording)
 			DvbManager::Prioritized);
 
 		if (device == NULL) {
-			kWarning() << "cannot find a suitable device";
+			Log("DvbRecordingFile::start: cannot find a suitable device");
 			return false;
 		}
 
@@ -415,6 +559,8 @@ bool DvbRecordingFile::start(const DvbRecording &recording)
 		}
 	}
 
+	manager->getRecordingModel()->setCurrentRecording(recording);
+
 	return true;
 }
 
@@ -444,6 +590,9 @@ void DvbRecordingFile::stop()
 	buffers.clear();
 	file.close();
 	channel = DvbSharedChannel();
+
+	manager->getRecordingModel()->executeActionAfterRecording(manager->getRecordingModel()->getCurrentRecording());
+	manager->getRecordingModel()->findNewRecordings();
 }
 
 void DvbRecordingFile::deviceStateChanged()
@@ -475,6 +624,8 @@ void DvbRecordingFile::deviceStateChanged()
 				device->startDescrambling(pmtSectionData, this);
 			}
 		} else {
+			// TODO
+
 			stop();
 		}
 	}
