@@ -1,7 +1,7 @@
 /*
  * dvbscan.cpp
  *
- * Copyright (C) 2008-2009 Christoph Pfister <christophpfister@gmail.com>
+ * Copyright (C) 2008-2011 Christoph Pfister <christophpfister@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #include "dvbscan.h"
 
 #include <QBitArray>
-#include <KDebug>
+#include "../log.h"
 #include "dvbdevice.h"
 #include "dvbsi.h"
 
@@ -120,7 +120,7 @@ bool DvbScanFilter::checkMultipleSection(const DvbStandardSection &section)
 	int sectionCount = section.lastSectionNumber() + 1;
 
 	if (section.sectionNumber() >= sectionCount) {
-		kDebug() << "current > last";
+		Log("DvbScanFilter::checkMultipleSection: current > last");
 		sectionCount = section.sectionNumber() + 1;
 	}
 
@@ -128,7 +128,8 @@ bool DvbScanFilter::checkMultipleSection(const DvbStandardSection &section)
 		multipleSections.resize(sectionCount);
 	} else {
 		if (multipleSections.size() != sectionCount) {
-			kDebug() << "inconsistent number of sections";
+			Log("DvbScanFilter::checkMultipleSection: "
+			    "inconsistent number of sections");
 
 			if (multipleSections.size() < sectionCount) {
 				multipleSections.resize(sectionCount);
@@ -235,7 +236,8 @@ void DvbScanFilter::processSection(const char *data, int size)
 
 void DvbScanFilter::timerEvent(QTimerEvent *)
 {
-	kWarning() << "timeout while reading section; type =" << type << "pid =" << pid;
+	Log("DvbScanFilter::timerEvent: timeout while reading section; type =") << type <<
+		QLatin1String("pid =") << pid;
 	scan->filterFinished(this);
 }
 
@@ -256,12 +258,12 @@ DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const QString &auto
 	device(device_), source(source_), isLive(false), isAuto(true), transponderIndex(0),
 	state(ScanTune), patIndex(0), activeFilters(0)
 {
-	if ((autoScanSource == "AUTO-Normal") || (autoScanSource == "AUTO-Offsets")) {
-		bool offsets = (autoScanSource == "AUTO-Offsets");
+	if ((autoScanSource == QLatin1String("AUTO-Normal")) || (autoScanSource == QLatin1String("AUTO-Offsets"))) {
+		bool offsets = (autoScanSource == QLatin1String("AUTO-Offsets"));
 
 		for (int frequency = 177500000; frequency <= 226500000; frequency += 7000000) {
-			DvbTransponder transponder(DvbTransponderBase::DvbT);
-			DvbTTransponder *dvbTTransponder = transponder.as<DvbTTransponder>();
+			DvbTransponder currentTransponder(DvbTransponderBase::DvbT);
+			DvbTTransponder *dvbTTransponder = currentTransponder.as<DvbTTransponder>();
 			dvbTTransponder->frequency = frequency;
 			dvbTTransponder->bandwidth = DvbTTransponder::Bandwidth7MHz;
 			dvbTTransponder->modulation = DvbTTransponder::ModulationAuto;
@@ -270,7 +272,7 @@ DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const QString &auto
 			dvbTTransponder->transmissionMode = DvbTTransponder::TransmissionModeAuto;
 			dvbTTransponder->guardInterval = DvbTTransponder::GuardIntervalAuto;
 			dvbTTransponder->hierarchy = DvbTTransponder::HierarchyNone;
-			transponders.append(transponder);
+			transponders.append(currentTransponder);
 		}
 
 		for (int frequency = 474000000; frequency <= 858000000; frequency += 8000000) {
@@ -287,9 +289,9 @@ DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const QString &auto
 					offset = 167000;
 				}
 
-				DvbTransponder transponder(DvbTransponderBase::DvbT);
+				DvbTransponder currentTransponder(DvbTransponderBase::DvbT);
 				DvbTTransponder *dvbTTransponder =
-					transponder.as<DvbTTransponder>();
+					currentTransponder.as<DvbTTransponder>();
 				dvbTTransponder->frequency = frequency + offset;
 				dvbTTransponder->bandwidth = DvbTTransponder::Bandwidth8MHz;
 				dvbTTransponder->modulation = DvbTTransponder::ModulationAuto;
@@ -300,10 +302,10 @@ DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const QString &auto
 				dvbTTransponder->guardInterval =
 					DvbTTransponder::GuardIntervalAuto;
 				dvbTTransponder->hierarchy = DvbTTransponder::HierarchyNone;
-				transponders.append(transponder);
+				transponders.append(currentTransponder);
 			}
 		}
-	} else if (autoScanSource == "AUTO-Australia") {
+	} else if (autoScanSource == QLatin1String("AUTO-Australia")) {
 		for (int frequency = 177500000; frequency <= 226500000; frequency += 7000000) {
 			for (int i = 0; i < 2; ++i) {
 				int offset = 0;
@@ -312,9 +314,9 @@ DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const QString &auto
 					offset = 125000;
 				}
 
-				DvbTransponder transponder(DvbTransponderBase::DvbT);
+				DvbTransponder currentTransponder(DvbTransponderBase::DvbT);
 				DvbTTransponder *dvbTTransponder =
-					transponder.as<DvbTTransponder>();
+					currentTransponder.as<DvbTTransponder>();
 				dvbTTransponder->frequency = frequency + offset;
 				dvbTTransponder->bandwidth = DvbTTransponder::Bandwidth7MHz;
 				dvbTTransponder->modulation = DvbTTransponder::ModulationAuto;
@@ -325,7 +327,7 @@ DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const QString &auto
 				dvbTTransponder->guardInterval =
 					DvbTTransponder::GuardIntervalAuto;
 				dvbTTransponder->hierarchy = DvbTTransponder::HierarchyNone;
-				transponders.append(transponder);
+				transponders.append(currentTransponder);
 			}
 		}
 
@@ -337,9 +339,9 @@ DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const QString &auto
 					offset = 125000;
 				}
 
-				DvbTransponder transponder(DvbTransponderBase::DvbT);
+				DvbTransponder currentTransponder(DvbTransponderBase::DvbT);
 				DvbTTransponder *dvbTTransponder =
-					transponder.as<DvbTTransponder>();
+					currentTransponder.as<DvbTTransponder>();
 				dvbTTransponder->frequency = frequency + offset;
 				dvbTTransponder->bandwidth = DvbTTransponder::Bandwidth7MHz;
 				dvbTTransponder->modulation = DvbTTransponder::ModulationAuto;
@@ -350,18 +352,18 @@ DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const QString &auto
 				dvbTTransponder->guardInterval =
 					DvbTTransponder::GuardIntervalAuto;
 				dvbTTransponder->hierarchy = DvbTTransponder::HierarchyNone;
-				transponders.append(transponder);
+				transponders.append(currentTransponder);
 			}
 		}
-	} else if (autoScanSource == "AUTO-Italy") {
+	} else if (autoScanSource == QLatin1String("AUTO-Italy")) {
 		static const int italyVhf[] = { 177500000, 186000000, 194500000, 203500000,
 						212500000, 219500000, 226500000 };
 
 		for (unsigned i = 0; i < (sizeof(italyVhf) / sizeof(italyVhf[0])); ++i) {
 			for (int j = 0; j < 2; ++j) {
-				DvbTransponder transponder(DvbTransponderBase::DvbT);
+				DvbTransponder currentTransponder(DvbTransponderBase::DvbT);
 				DvbTTransponder *dvbTTransponder =
-					transponder.as<DvbTTransponder>();
+					currentTransponder.as<DvbTTransponder>();
 				dvbTTransponder->frequency = italyVhf[i];
 				dvbTTransponder->bandwidth = ((j == 0) ?
 					DvbTTransponder::Bandwidth7MHz :
@@ -374,14 +376,14 @@ DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const QString &auto
 				dvbTTransponder->guardInterval =
 					DvbTTransponder::GuardIntervalAuto;
 				dvbTTransponder->hierarchy = DvbTTransponder::HierarchyNone;
-				transponders.append(transponder);
+				transponders.append(currentTransponder);
 			}
 		}
 
 		for (int frequency = 474000000; frequency <= 858000000; frequency += 8000000) {
-			DvbTransponder transponder(DvbTransponderBase::DvbT);
+			DvbTransponder currentTransponder(DvbTransponderBase::DvbT);
 			DvbTTransponder *dvbTTransponder =
-				transponder.as<DvbTTransponder>();
+				currentTransponder.as<DvbTTransponder>();
 			dvbTTransponder->frequency = frequency;
 			dvbTTransponder->bandwidth = DvbTTransponder::Bandwidth8MHz;
 			dvbTTransponder->modulation = DvbTTransponder::ModulationAuto;
@@ -390,13 +392,13 @@ DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const QString &auto
 			dvbTTransponder->transmissionMode = DvbTTransponder::TransmissionModeAuto;
 			dvbTTransponder->guardInterval = DvbTTransponder::GuardIntervalAuto;
 			dvbTTransponder->hierarchy = DvbTTransponder::HierarchyNone;
-			transponders.append(transponder);
+			transponders.append(currentTransponder);
 		}
-	} else if (autoScanSource == "AUTO-Taiwan") {
+	} else if (autoScanSource == QLatin1String("AUTO-Taiwan")) {
 		for (int frequency = 527000000; frequency <= 599000000; frequency += 6000000) {
-			DvbTransponder transponder(DvbTransponderBase::DvbT);
+			DvbTransponder currentTransponder(DvbTransponderBase::DvbT);
 			DvbTTransponder *dvbTTransponder =
-				transponder.as<DvbTTransponder>();
+				currentTransponder.as<DvbTTransponder>();
 			dvbTTransponder->frequency = frequency;
 			dvbTTransponder->bandwidth = DvbTTransponder::Bandwidth6MHz;
 			dvbTTransponder->modulation = DvbTTransponder::ModulationAuto;
@@ -405,7 +407,7 @@ DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const QString &auto
 			dvbTTransponder->transmissionMode = DvbTTransponder::TransmissionModeAuto;
 			dvbTTransponder->guardInterval = DvbTTransponder::GuardIntervalAuto;
 			dvbTTransponder->hierarchy = DvbTTransponder::HierarchyNone;
-			transponders.append(transponder);
+			transponders.append(currentTransponder);
 		}
 	}
 }
@@ -530,7 +532,7 @@ void DvbScan::updateState()
 				}
 
 				if (channel.name.isEmpty()) {
-					channel.name = QString("#0 %1:%2").
+					channel.name = QString(QLatin1String("#0 %1:%2")).
 						       arg(channel.transportStreamId).
 						       arg(channel.serviceId);
 				}
@@ -670,7 +672,7 @@ void DvbScan::processVct(const AtscVctSection &section)
 
 	for (AtscVctSectionEntry entry = section.entries(); (i > 0) && (entry.isValid());
 	     --i, entry.advance()) {
-		QString majorminor = QString("%1-%2 ").
+		QString majorminor = QString(QLatin1String("%1-%2 ")).
 			arg(entry.majorNumber(), 3, 10, QLatin1Char('0')).arg(entry.minorNumber());
 
 		DvbSdtEntry sdtEntry(entry.programNumber(), entry.sourceId(), entry.isScrambled());
