@@ -1,7 +1,7 @@
 /*
  * dvbsi.cpp
  *
- * Copyright (C) 2008-2010 Christoph Pfister <christophpfister@gmail.com>
+ * Copyright (C) 2008-2011 Christoph Pfister <christophpfister@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #include "dvbsi.h"
 
 #include <QTextCodec>
-#include <KDebug>
+#include "../log.h"
 
 void DvbSection::initSection(const char *data, int size)
 {
@@ -30,11 +30,10 @@ void DvbSection::initSection(const char *data, int size)
 		return;
 	}
 
-	int sectionLength = ((((static_cast<unsigned char>(data[1]) & 0xf) << 8) |
-		static_cast<unsigned char>(data[2])) + 3);
+	int sectionLength = ((((quint8(data[1]) & 0xf) << 8) | quint8(data[2])) + 3);
 
 	if (sectionLength > size) {
-		kDebug() << "adjusting length";
+		Log("DvbSection::initSection: adjusting length");
 		sectionLength = size;
 	}
 
@@ -46,8 +45,7 @@ int DvbStandardSection::verifyCrc32(const char *data, int size)
 	unsigned int crc32 = 0xffffffff;
 
 	for (int i = 0; i < size; ++i) {
-		crc32 = ((crc32 << 8) ^
-			crc32Table[(crc32 >> 24) ^ static_cast<unsigned char>(data[i])]);
+		crc32 = ((crc32 << 8) ^ crc32Table[(crc32 >> 24) ^ quint8(data[i])]);
 	}
 
 	return crc32;
@@ -175,7 +173,7 @@ public:
 		unsigned short diacriticalMark = 0;
 
 		for (; size > 0; ++input, --size) {
-			unsigned short value = table[static_cast<unsigned char>(*input)];
+			unsigned short value = table[quint8(*input)];
 
 			if (value == 0xffff) {
 				continue;
@@ -246,7 +244,7 @@ QString DvbSiText::convertText(const char *data, int size)
 	// determine encoding
 	TextEncoding encoding = (override6937 ? Iso8859_1 : Iso6937);
 
-	if (static_cast<unsigned char>(data[0]) < 0x20) {
+	if (quint8(data[0]) < 0x20) {
 		switch (data[0]) {
 		case 0x01: encoding = Iso8859_5; break;
 		case 0x02: encoding = Iso8859_6; break;
@@ -343,7 +341,7 @@ QString DvbSiText::convertText(const char *data, int size)
 			}
 		}
 
-		QString result = codecTable[encoding]->toUnicode(dest, destIt - dest);
+		QString result = codecTable[encoding]->toUnicode(dest, int(destIt - dest));
 		delete[] dest;
 
 		return result;
@@ -364,17 +362,17 @@ void DvbDescriptor::initDescriptor(const char *data, int size)
 {
 	if (size < 2) {
 		if (size != 0) {
-			kDebug() << "invalid descriptor";
+			Log("DvbDescriptor::initDescriptor: invalid descriptor");
 		}
 
 		initSectionData();
 		return;
 	}
 
-	int descriptorLength = (static_cast<unsigned char>(data[1]) + 2);
+	int descriptorLength = (quint8(data[1]) + 2);
 
 	if (descriptorLength > size) {
-		kDebug() << "adjusting length";
+		Log("DvbDescriptor::initDescriptor: adjusting length");
 		descriptorLength = size;
 	}
 
@@ -400,7 +398,7 @@ QString AtscPsipText::interpretTextData(const char *data, unsigned int len,
 	} else if (mode == 0x3f) {
 		// UTF-16
 		for (unsigned int i = 0; i < len; i += 2) {
-			QChar val = ((data[i] << 8)| data[i+1]);
+			QChar val = ((unsigned char)data[i] * 256) + (unsigned char)data[i+1];
 			result += val;
 		}
 	} else {
@@ -408,7 +406,7 @@ QString AtscPsipText::interpretTextData(const char *data, unsigned int len,
 		// 0x3e Standard Compression Scheme for UNICODE (SCSU)
 		// 0x40/0x41 Taiwan
 		// 0x48 South Korea
-		kWarning() << "Unsupported ATSC Text mode:" << mode;
+		Log("AtscPsipText::interpretTextData: Unsupported ATSC Text mode") << mode;
 	}
 	return result;
 }
@@ -421,7 +419,7 @@ QString AtscPsipText::convertText(const char *data, int size)
 		return QString();
 	}
 
-	unsigned int num_strings = static_cast<unsigned char>(data[0]);
+	unsigned int num_strings = quint8(data[0]);
 
 	if (num_strings == 0) {
 		return result;
@@ -435,24 +433,24 @@ QString AtscPsipText::convertText(const char *data, int size)
 	offset += 3;
 
 	if (offset > size) {
-		kDebug() << "adjusting length";
+		Log("AtscPsipText::convertText: adjusting length");
 		return result;
 	}
 
-	int num_segments = static_cast<unsigned char>(data[offset++]);
+	int num_segments = quint8(data[offset++]);
 
 	for (int j = 0; j < num_segments; j++) {
 		if ((offset + 3) > size) {
-			kDebug() << "adjusting length";
+			Log("AtscPsipText::convertText: adjusting length");
 			return result;
 		}
 
-		int comp_type = static_cast<unsigned char>(data[offset++]);
-		int mode = static_cast<unsigned char>(data[offset++]);
-		int num_bytes = static_cast<unsigned char>(data[offset++]);
+		int comp_type = quint8(data[offset++]);
+		int mode = quint8(data[offset++]);
+		int num_bytes = quint8(data[offset++]);
 
 		if ((offset + num_bytes) > size) {
-			kDebug() << "adjusting length";
+			Log("AtscPsipText::convertText: adjusting length");
 			return result;
 		}
 
@@ -469,7 +467,8 @@ QString AtscPsipText::convertText(const char *data, int size)
 			result +=
 				AtscHuffmanString::convertText(comp_string, num_bytes, comp_type);
 		} else {
-			kWarning() << "Unsupported compression / mode:" << comp_type << mode;
+			Log("AtscPsipText::convertText: Unsupported compression / mode") <<
+				comp_type << mode;
 		}
 
 		offset += num_bytes;
@@ -526,8 +525,7 @@ unsigned char AtscHuffmanString::getByte()
 		// Note this takes advantage of the fact that there is always
 		// at least one byte remaining (to avoid a read-past end
 		// condition)
-		unsigned char value =
-			((((data[0] << 8) | ((unsigned char) data[1])) >> (shift + 1)) & 0xff);
+		unsigned char value = ((((data[0] << 8) | quint8(data[1])) >> (shift + 1)) & 0xff);
 
 		bitsLeft -= 8;
 		data++;
@@ -1044,12 +1042,12 @@ void DvbSectionGenerator::initPat(int transportStreamId, int programNumber, int
 
 	char *data = startSection(16);
 	data[0] = 0x00;
-	data[3] = transportStreamId >> 8;
-	data[4] = transportStreamId;
-	data[8] = programNumber >> 8;
-	data[9] = programNumber;
-	data[10] = 0xe0 | (pmtPid >> 8);
-	data[11] = pmtPid;
+	data[3] = char(transportStreamId >> 8);
+	data[4] = char(transportStreamId);
+	data[8] = char(programNumber >> 8);
+	data[9] = char(programNumber);
+	data[10] = 0xe0 | char(pmtPid >> 8);
+	data[11] = char(pmtPid);
 	endSection(16, 0x00);
 }
 
@@ -1061,7 +1059,7 @@ void DvbSectionGenerator::initPmt(int pmtPid, const DvbPmtSection &section, cons
 
 	DvbPmtSectionEntry entry = section.entries();
 	memcpy(data, section.getData(), entry.getData() - section.getData());
-	int size = entry.getData() - section.getData();
+	int size = int(entry.getData() - section.getData());
 
 	while (entry.isValid()) {
 		if (pids.contains(entry.pid())) {
@@ -1080,7 +1078,7 @@ QByteArray DvbSectionGenerator::generatePackets()
 	char *data = packets.data();
 
 	for (int i = 3; i < packets.size(); i += 188) {
-		data[i] = (data[i] & 0xf0) | continuityCounter;
+		data[i] = (data[i] & 0xf0) | char(continuityCounter);
 		continuityCounter = (continuityCounter + 1) & 0x0f;
 	}
 
@@ -1103,13 +1101,13 @@ void DvbSectionGenerator::endSection(int sectionLength, int pid)
 	char *data = packets.data();
 
 	data[0] = 0x47;
-	data[1] = 0x40 | (pid >> 8);
-	data[2] = pid;
+	data[1] = 0x40 | char(pid >> 8);
+	data[2] = char(pid);
 	data[3] = 0x10;
 	data[4] = 0x00;
-	data[6] = 0xb0 | ((sectionLength - 3) >> 8);
-	data[7] = sectionLength - 3;
-	data[10] = 0xc1 | (versionNumber << 1);
+	data[6] = 0xb0 | char((sectionLength - 3) >> 8);
+	data[7] = char(sectionLength - 3);
+	data[10] = 0xc1 | char(versionNumber << 1);
 	data[11] = 0x00;
 	data[12] = 0x00;
 
@@ -1121,17 +1119,17 @@ void DvbSectionGenerator::endSection(int sectionLength, int pid)
 		crc32 = (crc32 << 8) ^ DvbStandardSection::crc32Table[(crc32 >> 24) ^ byte];
 	}
 
-	data[size - 4] = crc32 >> 24;
-	data[size - 3] = crc32 >> 16;
-	data[size - 2] = crc32 >> 8;
-	data[size - 1] = crc32;
+	data[size - 4] = char(crc32 >> 24);
+	data[size - 3] = char(crc32 >> 16);
+	data[size - 2] = char(crc32 >> 8);
+	data[size - 1] = char(crc32);
 
 	for (int i = 188; i < size; i += 188) {
 		// split the section into multiple packets if necessary
 		memmove(data + i + 4, data + i, size - i);
 		data[i] = 0x47;
-		data[i + 1] = pid >> 8;
-		data[i + 2] = pid;
+		data[i + 1] = char(pid >> 8);
+		data[i + 2] = char(pid);
 		data[i + 3] = 0x10; // continuity counter is filled out in generatePackets()
 		size += 4;
 	}
@@ -1183,7 +1181,7 @@ DvbPmtParser::DvbPmtParser(const DvbPmtSection &section) : videoPid(-1), teletex
 				if ((subtitleDescriptor.subtitleType() >= 0x01) &&
 				    (subtitleDescriptor.subtitleType() <= 0x03)) {
 					// FIXME how to deal with vbi and teletext subtitles?
-					kDebug() << "special subtitle found";
+					Log("DvbPmtParser::DvbPmtParser: special subtitle found");
 				}
 
 				// ISO 8859-1 equals to unicode range 0x0000 - 0x00ff
@@ -1209,7 +1207,7 @@ DvbPmtParser::DvbPmtParser(const DvbPmtSection &section) : videoPid(-1), teletex
 			if (videoPid < 0) {
 				videoPid = entry.pid();
 			} else {
-				kDebug() << "more than one video pid";
+				Log("DvbPmtParser::DvbPmtParser: more than one video pid");
 			}
 
 			break;
@@ -1228,7 +1226,8 @@ DvbPmtParser::DvbPmtParser(const DvbPmtSection &section) : videoPid(-1), teletex
 				if (teletextPid < 0) {
 					teletextPid = entry.pid();
 				} else {
-					kDebug() << "more than one teletext pid";
+					Log("DvbPmtParser::DvbPmtParser: "
+					    "more than one teletext pid");
 				}
 			}
 
@@ -1236,7 +1235,8 @@ DvbPmtParser::DvbPmtParser(const DvbPmtSection &section) : videoPid(-1), teletex
 				subtitlePids.append(qMakePair(entry.pid(), subtitleLanguage));
 
 				if (teletextPresent) {
-					kDebug() << "subtitle and teletext on the same pid";
+					Log("DvbPmtParser::DvbPmtParser: "
+					    "subtitle and teletext on the same pid");
 				}
 			}
 
@@ -1248,11 +1248,13 @@ DvbPmtParser::DvbPmtParser(const DvbPmtSection &section) : videoPid(-1), teletex
 
 		default:
 			if (!subtitleLanguage.isEmpty()) {
-				kDebug() << "subtitle with unexpected stream type found";
+				Log("DvbPmtParser::DvbPmtParser: "
+				    "subtitle with unexpected stream type found");
 			}
 
 			if (teletextPresent) {
-				kDebug() << "teletext with unexpected stream type found";
+				Log("DvbPmtParser::DvbPmtParser: "
+				    "teletext with unexpected stream type found");
 			}
 
 			break;
@@ -1264,26 +1266,26 @@ void AtscEitSectionEntry::initEitSectionEntry(const char *data, int size)
 {
 	if (size < 12) {
 		if (size != 0) {
-			kDebug() << "invalid entry";
+			Log("AtscEitSectionEntry::initEitSectionEntry: invalid entry");
 		}
 
 		initSectionData();
 		return;
 	}
 
-	titleLength = static_cast<unsigned char>(data[9]);
+	titleLength = quint8(data[9]);
 
 	if (titleLength > (size - 12)) {
-		kDebug() << "adjusting length";
+		Log("AtscEitSectionEntry::initEitSectionEntry: adjusting length");
 		titleLength = (size - 12);
 	}
 
 	// too ugly to be automatically generated
-	int entryLength = ((((static_cast<unsigned char>(data[10 + titleLength]) & 0xf) << 8) |
-		static_cast<unsigned char>(data[11 + titleLength])) + 12 + titleLength);
+	int entryLength = ((((quint8(data[10 + titleLength]) & 0xf) << 8) |
+		quint8(data[11 + titleLength])) + 12 + titleLength);
 
 	if (entryLength > size) {
-		kDebug() << "adjusting length";
+		Log("AtscEitSectionEntry::initEitSectionEntry: adjusting length");
 		entryLength = size;
 	}
 
@@ -1295,7 +1297,7 @@ void AtscEitSectionEntry::initEitSectionEntry(const char *data, int size)
 DvbLanguageDescriptor::DvbLanguageDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
 {
 	if (getLength() < 6) {
-		kDebug() << "invalid descriptor";
+		Log("DvbLanguageDescriptor::DvbLanguageDescriptor: invalid descriptor");
 		initSectionData();
 		return;
 	}
@@ -1304,7 +1306,7 @@ DvbLanguageDescriptor::DvbLanguageDescriptor(const DvbDescriptor &descriptor) :
 DvbSubtitleDescriptor::DvbSubtitleDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
 {
 	if (getLength() < 10) {
-		kDebug() << "invalid descriptor";
+		Log("DvbSubtitleDescriptor::DvbSubtitleDescriptor: invalid descriptor");
 		initSectionData();
 		return;
 	}
@@ -1313,7 +1315,7 @@ DvbSubtitleDescriptor::DvbSubtitleDescriptor(const DvbDescriptor &descriptor) :
 DvbServiceDescriptor::DvbServiceDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
 {
 	if (getLength() < 5) {
-		kDebug() << "invalid descriptor";
+		Log("DvbServiceDescriptor::DvbServiceDescriptor: invalid descriptor");
 		initSectionData();
 		return;
 	}
@@ -1321,14 +1323,14 @@ DvbServiceDescriptor::DvbServiceDescriptor(const DvbDescriptor &descriptor) : Dv
 	providerNameLength = at(3);
 
 	if (providerNameLength > (getLength() - 5)) {
-		kDebug() << "adjusting length";
+		Log("DvbServiceDescriptor::DvbServiceDescriptor: adjusting length");
 		providerNameLength = (getLength() - 5);
 	}
 
 	serviceNameLength = at(4 + providerNameLength);
 
 	if (serviceNameLength > (getLength() - (5 + providerNameLength))) {
-		kDebug() << "adjusting length";
+		Log("DvbServiceDescriptor::DvbServiceDescriptor: adjusting length");
 		serviceNameLength = (getLength() - (5 + providerNameLength));
 	}
 }
@@ -1336,7 +1338,7 @@ DvbServiceDescriptor::DvbServiceDescriptor(const DvbDescriptor &descriptor) : Dv
 DvbShortEventDescriptor::DvbShortEventDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
 {
 	if (getLength() < 7) {
-		kDebug() << "invalid descriptor";
+		Log("DvbShortEventDescriptor::DvbShortEventDescriptor: invalid descriptor");
 		initSectionData();
 		return;
 	}
@@ -1344,14 +1346,14 @@ DvbShortEventDescriptor::DvbShortEventDescriptor(const DvbDescriptor &descriptor
 	eventNameLength = at(5);
 
 	if (eventNameLength > (getLength() - 7)) {
-		kDebug() << "adjusting length";
+		Log("DvbShortEventDescriptor::DvbShortEventDescriptor: adjusting length");
 		eventNameLength = (getLength() - 7);
 	}
 
 	textLength = at(6 + eventNameLength);
 
 	if (textLength > (getLength() - (7 + eventNameLength))) {
-		kDebug() << "adjusting length";
+		Log("DvbShortEventDescriptor::DvbShortEventDescriptor: adjusting length");
 		textLength = (getLength() - (7 + eventNameLength));
 	}
 }
@@ -1359,7 +1361,7 @@ DvbShortEventDescriptor::DvbShortEventDescriptor(const DvbDescriptor &descriptor
 DvbExtendedEventDescriptor::DvbExtendedEventDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
 {
 	if (getLength() < 8) {
-		kDebug() << "invalid descriptor";
+		Log("DvbExtendedEventDescriptor::DvbExtendedEventDescriptor: invalid descriptor");
 		initSectionData();
 		return;
 	}
@@ -1367,14 +1369,14 @@ DvbExtendedEventDescriptor::DvbExtendedEventDescriptor(const DvbDescriptor &desc
 	itemsLength = at(6);
 
 	if (itemsLength > (getLength() - 8)) {
-		kDebug() << "adjusting length";
+		Log("DvbExtendedEventDescriptor::DvbExtendedEventDescriptor: adjusting length");
 		itemsLength = (getLength() - 8);
 	}
 
 	textLength = at(7 + itemsLength);
 
 	if (textLength > (getLength() - (8 + itemsLength))) {
-		kDebug() << "adjusting length";
+		Log("DvbExtendedEventDescriptor::DvbExtendedEventDescriptor: adjusting length");
 		textLength = (getLength() - (8 + itemsLength));
 	}
 }
@@ -1382,7 +1384,7 @@ DvbExtendedEventDescriptor::DvbExtendedEventDescriptor(const DvbDescriptor &desc
 DvbCableDescriptor::DvbCableDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
 {
 	if (getLength() < 13) {
-		kDebug() << "invalid descriptor";
+		Log("DvbCableDescriptor::DvbCableDescriptor: invalid descriptor");
 		initSectionData();
 		return;
 	}
@@ -1391,7 +1393,7 @@ DvbCableDescriptor::DvbCableDescriptor(const DvbDescriptor &descriptor) : DvbDes
 DvbSatelliteDescriptor::DvbSatelliteDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
 {
 	if (getLength() < 13) {
-		kDebug() << "invalid descriptor";
+		Log("DvbSatelliteDescriptor::DvbSatelliteDescriptor: invalid descriptor");
 		initSectionData();
 		return;
 	}
@@ -1400,7 +1402,7 @@ DvbSatelliteDescriptor::DvbSatelliteDescriptor(const DvbDescriptor &descriptor)
 DvbTerrestrialDescriptor::DvbTerrestrialDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
 {
 	if (getLength() < 13) {
-		kDebug() << "invalid descriptor";
+		Log("DvbTerrestrialDescriptor::DvbTerrestrialDescriptor: invalid descriptor");
 		initSectionData();
 		return;
 	}
@@ -1409,7 +1411,7 @@ DvbTerrestrialDescriptor::DvbTerrestrialDescriptor(const DvbDescriptor &descript
 AtscChannelNameDescriptor::AtscChannelNameDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
 {
 	if (getLength() < 2) {
-		kDebug() << "invalid descriptor";
+		Log("AtscChannelNameDescriptor::AtscChannelNameDescriptor: invalid descriptor");
 		initSectionData();
 		return;
 	}
@@ -1419,7 +1421,7 @@ void DvbPatSectionEntry::initPatSectionEntry(const char *data, int size)
 {
 	if (size < 4) {
 		if (size != 0) {
-			kDebug() << "invalid entry";
+			Log("DvbPatSectionEntry::initPatSectionEntry: invalid entry");
 		}
 
 		initSectionData();
@@ -1433,17 +1435,17 @@ void DvbPmtSectionEntry::initPmtSectionEntry(const char *data, int size)
 {
 	if (size < 5) {
 		if (size != 0) {
-			kDebug() << "invalid entry";
+			Log("DvbPmtSectionEntry::initPmtSectionEntry: invalid entry");
 		}
 
 		initSectionData();
 		return;
 	}
 
-	int entryLength = ((((static_cast<unsigned char>(data[3]) & 0xf) << 8) | static_cast<unsigned char>(data[4])) + 5);
+	int entryLength = ((((quint8(data[3]) & 0xf) << 8) | quint8(data[4])) + 5);
 
 	if (entryLength > size) {
-		kDebug() << "adjusting length";
+		Log("DvbPmtSectionEntry::initPmtSectionEntry: adjusting length");
 		entryLength = size;
 	}
 
@@ -1454,17 +1456,17 @@ void DvbSdtSectionEntry::initSdtSectionEntry(const char *data, int size)
 {
 	if (size < 5) {
 		if (size != 0) {
-			kDebug() << "invalid entry";
+			Log("DvbSdtSectionEntry::initSdtSectionEntry: invalid entry");
 		}
 
 		initSectionData();
 		return;
 	}
 
-	int entryLength = ((((static_cast<unsigned char>(data[3]) & 0xf) << 8) | static_cast<unsigned char>(data[4])) + 5);
+	int entryLength = ((((quint8(data[3]) & 0xf) << 8) | quint8(data[4])) + 5);
 
 	if (entryLength > size) {
-		kDebug() << "adjusting length";
+		Log("DvbSdtSectionEntry::initSdtSectionEntry: adjusting length");
 		entryLength = size;
 	}
 
@@ -1475,17 +1477,17 @@ void DvbEitSectionEntry::initEitSectionEntry(const char *data, int size)
 {
 	if (size < 12) {
 		if (size != 0) {
-			kDebug() << "invalid entry";
+			Log("DvbEitSectionEntry::initEitSectionEntry: invalid entry");
 		}
 
 		initSectionData();
 		return;
 	}
 
-	int entryLength = ((((static_cast<unsigned char>(data[10]) & 0xf) << 8) | static_cast<unsigned char>(data[11])) + 12);
+	int entryLength = ((((quint8(data[10]) & 0xf) << 8) | quint8(data[11])) + 12);
 
 	if (entryLength > size) {
-		kDebug() << "adjusting length";
+		Log("DvbEitSectionEntry::initEitSectionEntry: adjusting length");
 		entryLength = size;
 	}
 
@@ -1496,17 +1498,17 @@ void DvbNitSectionEntry::initNitSectionEntry(const char *data, int size)
 {
 	if (size < 6) {
 		if (size != 0) {
-			kDebug() << "invalid entry";
+			Log("DvbNitSectionEntry::initNitSectionEntry: invalid entry");
 		}
 
 		initSectionData();
 		return;
 	}
 
-	int entryLength = ((((static_cast<unsigned char>(data[4]) & 0xf) << 8) | static_cast<unsigned char>(data[5])) + 6);
+	int entryLength = ((((quint8(data[4]) & 0xf) << 8) | quint8(data[5])) + 6);
 
 	if (entryLength > size) {
-		kDebug() << "adjusting length";
+		Log("DvbNitSectionEntry::initNitSectionEntry: adjusting length");
 		entryLength = size;
 	}
 
@@ -1517,17 +1519,17 @@ void AtscMgtSectionEntry::initMgtSectionEntry(const char *data, int size)
 {
 	if (size < 11) {
 		if (size != 0) {
-			kDebug() << "invalid entry";
+			Log("AtscMgtSectionEntry::initMgtSectionEntry: invalid entry");
 		}
 
 		initSectionData();
 		return;
 	}
 
-	int entryLength = ((((static_cast<unsigned char>(data[9]) & 0xf) << 8) | static_cast<unsigned char>(data[10])) + 11);
+	int entryLength = ((((quint8(data[9]) & 0xf) << 8) | quint8(data[10])) + 11);
 
 	if (entryLength > size) {
-		kDebug() << "adjusting length";
+		Log("AtscMgtSectionEntry::initMgtSectionEntry: adjusting length");
 		entryLength = size;
 	}
 
@@ -1538,17 +1540,17 @@ void AtscVctSectionEntry::initVctSectionEntry(const char *data, int size)
 {
 	if (size < 32) {
 		if (size != 0) {
-			kDebug() << "invalid entry";
+			Log("AtscVctSectionEntry::initVctSectionEntry: invalid entry");
 		}
 
 		initSectionData();
 		return;
 	}
 
-	int entryLength = ((((static_cast<unsigned char>(data[30]) & 0x3) << 8) | static_cast<unsigned char>(data[31])) + 32);
+	int entryLength = ((((quint8(data[30]) & 0x3) << 8) | quint8(data[31])) + 32);
 
 	if (entryLength > size) {
-		kDebug() << "adjusting length";
+		Log("AtscVctSectionEntry::initVctSectionEntry: adjusting length");
 		entryLength = size;
 	}
 
@@ -1576,7 +1578,7 @@ void DvbPmtSection::initPmtSection(const char *data, int size)
 	descriptorsLength = ((at(10) & 0xf) << 8) | at(11);
 
 	if (descriptorsLength > (getLength() - 16)) {
-		kDebug() << "adjusting length";
+		Log("DvbPmtSection::initPmtSection: adjusting length");
 		descriptorsLength = (getLength() - 16);
 	}
 }
@@ -1612,14 +1614,14 @@ void DvbNitSection::initNitSection(const char *data, int size)
 	descriptorsLength = ((at(8) & 0xf) << 8) | at(9);
 
 	if (descriptorsLength > (getLength() - 16)) {
-		kDebug() << "adjusting length";
+		Log("DvbNitSection::initNitSection: adjusting length");
 		descriptorsLength = (getLength() - 16);
 	}
 
 	entriesLength = ((at(10 + descriptorsLength) & 0xf) << 8) | at(11 + descriptorsLength);
 
 	if (entriesLength > (getLength() - (16 + descriptorsLength))) {
-		kDebug() << "adjusting length";
+		Log("DvbNitSection::initNitSection: adjusting length");
 		entriesLength = (getLength() - (16 + descriptorsLength));
 	}
 }
