@@ -1,7 +1,7 @@
 /*
  * mainwindow.cpp
  *
- * Copyright (C) 2007-2009 Christoph Pfister <christophpfister@gmail.com>
+ * Copyright (C) 2007-2011 Christoph Pfister <christophpfister@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,12 +22,9 @@
 
 #include <QDBusConnection>
 #include <QHoverEvent>
-#include <QLabel>
-#include <QSpinBox>
 #include <QStackedLayout>
 #include <KActionCollection>
 #include <KCmdLineOptions>
-#include <KComboBox>
 #include <KFileDialog>
 #include <KInputDialog>
 #include <kio/deletejob.h>
@@ -40,6 +37,8 @@
 #include <KToolBar>
 #include "dvb/dvbtab.h"
 #include "playlist/playlisttab.h"
+#include "configuration.h"
+#include "configurationdialog.h"
 #include "dbusobjects.h"
 
 class StackedLayout : public QStackedLayout
@@ -83,28 +82,28 @@ StartTab::StartTab(MainWindow *mainWindow)
 	gridLayout->setSpacing(15);
 
 	QAbstractButton *button =
-		addShortcut(i18n("&1 Play File"), KIcon("video-x-generic"), this);
+		addShortcut(i18n("&1 Play File"), KIcon(QLatin1String("video-x-generic")), this);
 	button->setShortcut(Qt::Key_1);
 	connect(button, SIGNAL(clicked()), mainWindow, SLOT(open()));
 	gridLayout->addWidget(button, 0, 0);
 
-	button = addShortcut(i18n("&2 Play Audio CD"), KIcon("media-optical-audio"), this);
+	button = addShortcut(i18n("&2 Play Audio CD"), KIcon(QLatin1String("media-optical-audio")), this);
 	button->setShortcut(Qt::Key_2);
 	connect(button, SIGNAL(clicked()), mainWindow, SLOT(openAudioCd()));
 	gridLayout->addWidget(button, 0, 1);
 
-	button = addShortcut(i18n("&3 Play Video CD"), KIcon("media-optical"), this);
+	button = addShortcut(i18n("&3 Play Video CD"), KIcon(QLatin1String("media-optical")), this);
 	button->setShortcut(Qt::Key_3);
 	connect(button, SIGNAL(clicked()), mainWindow, SLOT(openVideoCd()));
 	gridLayout->addWidget(button, 0, 2);
 
-	button = addShortcut(i18n("&4 Play DVD"), KIcon("media-optical"), this);
+	button = addShortcut(i18n("&4 Play DVD"), KIcon(QLatin1String("media-optical")), this);
 	button->setShortcut(Qt::Key_4);
 	connect(button, SIGNAL(clicked()), mainWindow, SLOT(openDvd()));
 	gridLayout->addWidget(button, 1, 0);
 
 #if HAVE_DVB == 1
-	button = addShortcut(i18n("&5 Digital TV"), KIcon("video-television"), this);
+	button = addShortcut(i18n("&5 Digital TV"), KIcon(QLatin1String("video-television")), this);
 	button->setShortcut(Qt::Key_5);
 	connect(button, SIGNAL(clicked()), mainWindow, SLOT(playDvb()));
 	gridLayout->addWidget(button, 1, 1);
@@ -146,132 +145,6 @@ PlayerTab::PlayerTab(MediaWidget *mediaWidget_) : mediaWidget(mediaWidget_)
 	layout->setMargin(0);
 }
 
-class ConfigurationDialog : public KDialog
-{
-public:
-	enum StartupDisplayMode {
-		StartupNormalMode,
-		StartupMinimalMode,
-		StartupFullScreenMode,
-		StartupRememberLastSetting
-	};
-
-	static StartupDisplayMode getStartupDisplayMode();
-	static void setStartupDisplayMode(StartupDisplayMode startupDisplayMode);
-
-	ConfigurationDialog(MediaWidget *mediaWidget_, QWidget *parent);
-	~ConfigurationDialog();
-
-	void accept();
-
-private:
-	MediaWidget *mediaWidget;
-	KComboBox *startupDisplayModeBox;
-	QSpinBox *shortSkipBox;
-	QSpinBox *longSkipBox;
-};
-
-ConfigurationDialog::StartupDisplayMode ConfigurationDialog::getStartupDisplayMode()
-{
-	StartupDisplayMode startupDisplayMode = StartupNormalMode;
-
-	switch (KGlobal::config()->group("MainWindow").readEntry("StartupDisplayMode", 0)) {
-	case 0: startupDisplayMode = StartupNormalMode; break;
-	case 1: startupDisplayMode = StartupMinimalMode; break;
-	case 2: startupDisplayMode = StartupFullScreenMode; break;
-	case 3: startupDisplayMode = StartupRememberLastSetting; break;
-	}
-
-	return startupDisplayMode;
-}
-
-void ConfigurationDialog::setStartupDisplayMode(StartupDisplayMode startupDisplayMode)
-{
-	int value = 0;
-
-	switch (startupDisplayMode) {
-	case StartupNormalMode: value = 0; break;
-	case StartupMinimalMode: value = 1; break;
-	case StartupFullScreenMode: value = 2; break;
-	case StartupRememberLastSetting: value = 3; break;
-	}
-
-	KGlobal::config()->group("MainWindow").writeEntry("StartupDisplayMode", value);
-}
-
-ConfigurationDialog::ConfigurationDialog(MediaWidget *mediaWidget_, QWidget *parent) :
-	KDialog(parent), mediaWidget(mediaWidget_)
-{
-	setCaption(i18nc("dialog", "Configure Kaffeine"));
-
-	QWidget *widget = new QWidget(this);
-	QGridLayout *gridLayout = new QGridLayout(widget);
-
-	gridLayout->addWidget(new QLabel(i18nc("@label:listbox", "Startup display mode:"), widget),
-		0, 0);
-
-	int index = 0;
-
-	switch (getStartupDisplayMode()) {
-	case StartupNormalMode: index = 0; break;
-	case StartupMinimalMode: index = 1; break;
-	case StartupFullScreenMode: index = 2; break;
-	case StartupRememberLastSetting: index = 3; break;
-	}
-
-	startupDisplayModeBox = new KComboBox(widget);
-	startupDisplayModeBox->addItem(i18nc("@item:inlistbox 'Startup display mode:'",
-		"Normal Mode"));
-	startupDisplayModeBox->addItem(i18nc("@item:inlistbox 'Startup display mode:'",
-		"Minimal Mode"));
-	startupDisplayModeBox->addItem(i18nc("@item:inlistbox 'Startup display mode:'",
-		"Full Screen Mode"));
-	startupDisplayModeBox->addItem(i18nc("@item:inlistbox 'Startup display mode:'",
-		"Remember Last Setting"));
-	startupDisplayModeBox->setCurrentIndex(index);
-	gridLayout->addWidget(startupDisplayModeBox, 0, 1);
-
-	gridLayout->addWidget(new QLabel(i18nc("'Configure Kaffeine' dialog",
-		"Short skip duration:"), widget), 1, 0);
-
-	shortSkipBox = new QSpinBox(widget);
-	shortSkipBox->setRange(1, 600);
-	shortSkipBox->setValue(mediaWidget->getShortSkipDuration());
-	gridLayout->addWidget(shortSkipBox, 1, 1);
-
-	gridLayout->addWidget(new QLabel(i18nc("'Configure Kaffeine' dialog",
-		"Long skip duration:"), widget), 2, 0);
-
-	longSkipBox = new QSpinBox(widget);
-	longSkipBox->setRange(1, 600);
-	longSkipBox->setValue(mediaWidget->getLongSkipDuration());
-	gridLayout->addWidget(longSkipBox, 2, 1);
-
-	setMainWidget(widget);
-}
-
-ConfigurationDialog::~ConfigurationDialog()
-{
-}
-
-void ConfigurationDialog::accept()
-{
-	StartupDisplayMode displayMode = StartupNormalMode;
-
-	switch (startupDisplayModeBox->currentIndex()) {
-	case 0: displayMode = StartupNormalMode; break;
-	case 1: displayMode = StartupMinimalMode; break;
-	case 2: displayMode = StartupFullScreenMode; break;
-	case 3: displayMode = StartupRememberLastSetting; break;
-	}
-
-	setStartupDisplayMode(displayMode);
-	mediaWidget->setShortSkipDuration(shortSkipBox->value());
-	mediaWidget->setLongSkipDuration(longSkipBox->value());
-
-	KDialog::accept();
-}
-
 MainWindow::MainWindow()
 {
 	// menu structure
@@ -283,41 +156,41 @@ MainWindow::MainWindow()
 	menuBar->addMenu(menu);
 
 	KAction *action = KStandardAction::open(this, SLOT(open()), collection);
-	menu->addAction(collection->addAction("file_open", action));
+	menu->addAction(collection->addAction(QLatin1String("file_open"), action));
 
-	action = new KAction(KIcon("text-html"),
+	action = new KAction(KIcon(QLatin1String("text-html")),
 		i18nc("@action:inmenu", "Open URL..."), collection);
 	action->setShortcut(Qt::CTRL | Qt::Key_U);
 	connect(action, SIGNAL(triggered(bool)), this, SLOT(openUrl()));
-	menu->addAction(collection->addAction("file_open_url", action));
+	menu->addAction(collection->addAction(QLatin1String("file_open_url"), action));
 
 	actionOpenRecent = KStandardAction::openRecent(this, SLOT(openUrl(KUrl)), collection);
 	actionOpenRecent->loadEntries(KGlobal::config()->group("Recent Files"));
-	menu->addAction(collection->addAction("file_open_recent", actionOpenRecent));
+	menu->addAction(collection->addAction(QLatin1String("file_open_recent"), actionOpenRecent));
 
 	menu->addSeparator();
 
-	action = new KAction(KIcon("media-optical-audio"), i18n("Play Audio CD"), collection);
+	action = new KAction(KIcon(QLatin1String("media-optical-audio")), i18n("Play Audio CD"), collection);
 	connect(action, SIGNAL(triggered(bool)), this, SLOT(openAudioCd()));
-	menu->addAction(collection->addAction("file_play_audiocd", action));
+	menu->addAction(collection->addAction(QLatin1String("file_play_audiocd"), action));
 
-	action = new KAction(KIcon("media-optical"), i18n("Play Video CD"), collection);
+	action = new KAction(KIcon(QLatin1String("media-optical")), i18n("Play Video CD"), collection);
 	connect(action, SIGNAL(triggered(bool)), this, SLOT(openVideoCd()));
-	menu->addAction(collection->addAction("file_play_videocd", action));
+	menu->addAction(collection->addAction(QLatin1String("file_play_videocd"), action));
 
-	action = new KAction(KIcon("media-optical"), i18n("Play DVD"), collection);
+	action = new KAction(KIcon(QLatin1String("media-optical")), i18n("Play DVD"), collection);
 	connect(action, SIGNAL(triggered(bool)), this, SLOT(openDvd()));
-	menu->addAction(collection->addAction("file_play_dvd", action));
+	menu->addAction(collection->addAction(QLatin1String("file_play_dvd"), action));
 
-	action = new KAction(KIcon("media-optical"), i18nc("@action:inmenu", "Play DVD Folder"),
+	action = new KAction(KIcon(QLatin1String("media-optical")), i18nc("@action:inmenu", "Play DVD Folder"),
 		collection);
 	connect(action, SIGNAL(triggered()), this, SLOT(playDvdFolder()));
-	menu->addAction(collection->addAction("file_play_dvd_folder", action));
+	menu->addAction(collection->addAction(QLatin1String("file_play_dvd_folder"), action));
 
 	menu->addSeparator();
 
 	action = KStandardAction::quit(this, SLOT(close()), collection);
-	menu->addAction(collection->addAction("file_quit", action));
+	menu->addAction(collection->addAction(QLatin1String("file_quit"), action));
 
 	KMenu *playerMenu = new KMenu(i18n("&Playback"), this);
 	menuBar->addMenu(playerMenu);
@@ -334,26 +207,26 @@ MainWindow::MainWindow()
 	menuBar->addMenu(menu);
 
 	action = KStandardAction::keyBindings(this, SLOT(configureKeys()), collection);
-	menu->addAction(collection->addAction("settings_keys", action));
+	menu->addAction(collection->addAction(QLatin1String("settings_keys"), action));
 
 	action = KStandardAction::preferences(this, SLOT(configureKaffeine()), collection);
-	menu->addAction(collection->addAction("settings_kaffeine", action));
+	menu->addAction(collection->addAction(QLatin1String("settings_kaffeine"), action));
 
 	menuBar->addSeparator();
 	menuBar->addMenu(helpMenu());
 
 	// navigation bar - keep in sync with TabIndex enum!
 
-	navigationBar = new KToolBar("navigation_bar", this, Qt::LeftToolBarArea);
+	navigationBar = new KToolBar(QLatin1String("navigation_bar"), this, Qt::LeftToolBarArea);
 	connect(navigationBar, SIGNAL(orientationChanged(Qt::Orientation)),
 		this, SLOT(navigationBarOrientationChanged(Qt::Orientation)));
 
 	tabBar = new KTabBar(navigationBar);
-	tabBar->addTab(KIcon("start-here-kde"), i18n("Start"));
-	tabBar->addTab(KIcon("kaffeine"), i18n("Playback"));
-	tabBar->addTab(KIcon("view-media-playlist"), i18n("Playlist"));
+	tabBar->addTab(KIcon(QLatin1String("start-here-kde")), i18n("Start"));
+	tabBar->addTab(KIcon(QLatin1String("kaffeine")), i18n("Playback"));
+	tabBar->addTab(KIcon(QLatin1String("view-media-playlist")), i18n("Playlist"));
 #if HAVE_DVB == 1
-	tabBar->addTab(KIcon("video-television"), i18n("Television"));
+	tabBar->addTab(KIcon(QLatin1String("video-television")), i18n("Television"));
 #endif /* HAVE_DVB == 1 */
 	tabBar->setShape(KTabBar::RoundedWest);
 	tabBar->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
@@ -362,7 +235,7 @@ MainWindow::MainWindow()
 
 	// control bar
 
-	controlBar = new KToolBar("control_bar", this, Qt::BottomToolBarArea);
+	controlBar = new KToolBar(QLatin1String("control_bar"), this, Qt::BottomToolBarArea);
 	controlBar->setToolButtonStyle(Qt::ToolButtonIconOnly);
 
 	autoHideControlBar = false;
@@ -380,7 +253,8 @@ MainWindow::MainWindow()
 	mediaWidget = new MediaWidget(playerMenu, controlBar, collection, widget);
 	connect(mediaWidget, SIGNAL(displayModeChanged()), this, SLOT(displayModeChanged()));
 	connect(mediaWidget, SIGNAL(changeCaption(QString)), this, SLOT(setCaption(QString)));
-	connect(mediaWidget, SIGNAL(resizeToVideo(int)), this, SLOT(resizeToVideo(int)));
+	connect(mediaWidget, SIGNAL(resizeToVideo(MediaWidget::ResizeFactor)),
+		this, SLOT(resizeToVideo(MediaWidget::ResizeFactor)));
 
 	// tabs - keep in sync with TabIndex enum!
 
@@ -425,42 +299,42 @@ MainWindow::MainWindow()
 	controlBar->setToolButtonStyle(Qt::ToolButtonIconOnly);
 
 	KStatusNotifierItem *trayIcon = new KStatusNotifierItem(this);
-	trayIcon->setIconByName("kaffeine");
+	trayIcon->setIconByName(QLatin1String("kaffeine"));
 	trayIcon->setStatus(KStatusNotifierItem::Active);
-	trayIcon->setToolTipIconByName("kaffeine");
+	trayIcon->setToolTipIconByName(QLatin1String("kaffeine"));
 	trayIcon->setToolTipTitle(i18n("Kaffeine"));
 
 	// initialize random number generator
 	qsrand(QTime().msecsTo(QTime::currentTime()));
 
 	// initialize dbus objects
-	QDBusConnection::sessionBus().registerObject("/", new MprisRootObject(this),
+	QDBusConnection::sessionBus().registerObject(QLatin1String("/"), new MprisRootObject(this),
 		QDBusConnection::ExportAllContents);
-	QDBusConnection::sessionBus().registerObject("/Player",
+	QDBusConnection::sessionBus().registerObject(QLatin1String("/Player"),
 		new MprisPlayerObject(this, mediaWidget, playlistTab, this),
 		QDBusConnection::ExportAllContents);
-	QDBusConnection::sessionBus().registerObject("/TrackList",
+	QDBusConnection::sessionBus().registerObject(QLatin1String("/TrackList"),
 		new MprisTrackListObject(playlistTab, this), QDBusConnection::ExportAllContents);
 #if HAVE_DVB == 1
-	QDBusConnection::sessionBus().registerObject("/Television",
+	QDBusConnection::sessionBus().registerObject(QLatin1String("/Television"),
 		new DBusTelevisionObject(dvbTab, this), QDBusConnection::ExportAllContents);
 #endif /* HAVE_DVB == 1 */
-	QDBusConnection::sessionBus().registerService("org.mpris.kaffeine");
+	QDBusConnection::sessionBus().registerService(QLatin1String("org.mpris.kaffeine"));
 
 	show();
 
 	// set display mode
-	switch (ConfigurationDialog::getStartupDisplayMode()) {
-	case ConfigurationDialog::StartupNormalMode:
+	switch (Configuration::instance()->getStartupDisplayMode()) {
+	case Configuration::StartupNormalMode:
 		// nothing to do
 		break;
-	case ConfigurationDialog::StartupMinimalMode:
+	case Configuration::StartupMinimalMode:
 		mediaWidget->setDisplayMode(MediaWidget::MinimalMode);
 		break;
-	case ConfigurationDialog::StartupFullScreenMode:
+	case Configuration::StartupFullScreenMode:
 		mediaWidget->setDisplayMode(MediaWidget::FullScreenMode);
 		break;
-	case ConfigurationDialog::StartupRememberLastSetting: {
+	case Configuration::StartupRememberLastSetting: {
 		int value = KGlobal::config()->group("MainWindow").readEntry("DisplayMode", 0);
 
 		switch (value) {
@@ -494,6 +368,7 @@ MainWindow::~MainWindow()
 	case MediaWidget::NormalMode: value = 0; break;
 	case MediaWidget::MinimalMode: value = 1; break;
 	case MediaWidget::FullScreenMode: value = 2; break;
+	case MediaWidget::FullScreenReturnToMinimalMode: value = 2; break;
 	}
 
 	KGlobal::config()->group("MainWindow").writeEntry("DisplayMode", value);
@@ -618,14 +493,20 @@ void MainWindow::parseArgs()
 
 void MainWindow::displayModeChanged()
 {
-	if (mediaWidget->getDisplayMode() == MediaWidget::FullScreenMode) {
+	switch (mediaWidget->getDisplayMode()) {
+	case MediaWidget::FullScreenMode:
+	case MediaWidget::FullScreenReturnToMinimalMode:
 		setWindowState(windowState() | Qt::WindowFullScreen);
-	} else {
+		break;
+	case MediaWidget::MinimalMode:
+	case MediaWidget::NormalMode:
 		setWindowState(windowState() & (~Qt::WindowFullScreen));
+		break;
 	}
 
 	switch (mediaWidget->getDisplayMode()) {
 	case MediaWidget::FullScreenMode:
+	case MediaWidget::FullScreenReturnToMinimalMode:
 	case MediaWidget::MinimalMode:
 		menuBar()->hide();
 		navigationBar->hide();
@@ -717,14 +598,29 @@ void MainWindow::playDvb()
 	dvbTab->playLastChannel();
 }
 
-void MainWindow::resizeToVideo(int factor)
+void MainWindow::resizeToVideo(MediaWidget::ResizeFactor resizeFactor)
 {
 	if (!isFullScreen() && !mediaWidget->sizeHint().isEmpty()) {
 		if (isMaximized()) {
 			setWindowState(windowState() & ~Qt::WindowMaximized);
 		}
 
-		resize(size() - centralWidget()->size() + factor * mediaWidget->sizeHint());
+		QSize videoSize;
+
+		switch (resizeFactor) {
+		case MediaWidget::ResizeOff:
+			break;
+		case MediaWidget::OriginalSize:
+			videoSize = mediaWidget->sizeHint();
+			break;
+		case MediaWidget::DoubleSize:
+			videoSize = (2 * mediaWidget->sizeHint());
+			break;
+		}
+
+		if (!videoSize.isEmpty()) {
+			resize(size() - centralWidget()->size() + videoSize);
+		}
 	}
 }
 
@@ -735,7 +631,7 @@ void MainWindow::configureKeys()
 
 void MainWindow::configureKaffeine()
 {
-	KDialog *dialog = new ConfigurationDialog(mediaWidget, this);
+	KDialog *dialog = new ConfigurationDialog(this);
 	dialog->setAttribute(Qt::WA_DeleteOnClose, true);
 	dialog->setModal(true);
 	dialog->show();
@@ -784,7 +680,7 @@ bool MainWindow::event(QEvent *event)
 
 	// FIXME we depend on QEvent::HoverMove (instead of QEvent::MouseMove)
 	// but the latter depends on mouse tracking being enabled on this widget
-	// and all its children (especially the phonon video widget) ...
+	// and all its children (especially the video widget) ...
 
 	if ((event->type() == QEvent::HoverMove) && autoHideControlBar) {
 		int y = reinterpret_cast<QHoverEvent *> (event)->pos().y();
