@@ -1,7 +1,7 @@
 /*
  * mediawidget_p.h
  *
- * Copyright (C) 2007-2010 Christoph Pfister <christophpfister@gmail.com>
+ * Copyright (C) 2007-2011 Christoph Pfister <christophpfister@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,40 +23,9 @@
 
 #include <QSlider>
 #include <KDialog>
+#include "mediawidget.h"
 
-class QSocketNotifier;
 class QTimeEdit;
-class MediaWidget;
-
-class DvbFeed : public QObject
-{
-	Q_OBJECT
-public:
-	explicit DvbFeed(QObject *parent);
-	~DvbFeed();
-
-	KUrl getUrl() const;
-	void writeData(const QByteArray &data);
-	void endOfData();
-
-	bool timeShiftPrepared;
-	bool timeShiftActive;
-	bool ignoreSourceChange;
-	QStringList audioChannels;
-	QStringList subtitles;
-
-private slots:
-	void readyWrite();
-
-private:
-	bool flush();
-
-	KUrl url;
-	int readFd;
-	int writeFd;
-	QSocketNotifier *notifier;
-	QList<QByteArray> buffers;
-};
 
 class JumpToPositionDialog : public KDialog
 {
@@ -81,4 +50,54 @@ private:
 	void mousePressEvent(QMouseEvent *event);
 };
 
+class MediaSourceUrl : public MediaSource
+{
+public:
+	MediaSourceUrl(const KUrl &url_, const KUrl &subtitleUrl_) : url(url_),
+		subtitleUrl(subtitleUrl_) { }
+	~MediaSourceUrl() { }
+
+	Type getType() const { return Url; }
+	KUrl getUrl() const { return url; }
+
+	KUrl url;
+	KUrl subtitleUrl;
+};
+
+class MediaSourceAudioCd : public MediaSource
+{
+public:
+	explicit MediaSourceAudioCd(const KUrl &url_) : url(url_) { }
+	~MediaSourceAudioCd() { }
+
+	Type getType() const { return AudioCd; }
+	KUrl getUrl() const { return url; }
+
+	KUrl url;
+};
+
+class MediaSourceVideoCd : public MediaSource
+{
+public:
+	explicit MediaSourceVideoCd(const KUrl &url_) : url(url_) { }
+	~MediaSourceVideoCd() { }
+
+	Type getType() const { return VideoCd; }
+	KUrl getUrl() const { return url; }
+
+	KUrl url;
+};
+
+class MediaSourceDvd : public MediaSource
+{
+public:
+	explicit MediaSourceDvd(const KUrl &url_) : url(url_) { }
+	~MediaSourceDvd() { }
+
+	Type getType() const { return Dvd; }
+	KUrl getUrl() const { return url; }
+
+	KUrl url;
+};
+
 #endif /* MEDIAWIDGET_P_H */
